#!/usr/bin/python

import os
import sys
import json
import time
import hashlib
from os.path import join, exists
from os import system

from epy import epymils
from epy.epymils import paramils, setting, eargs
from epy.epymils.log import *

setting.TIMEOUT_GLOBAL = int(os.getenv("BST_TIMEOUT_GLOBAL",800))
setting.TIMEOUT_FINETUNES = int(os.getenv("BST_TIMEOUT_FINETUNES",10))
setting.TIMEOUT_ENIGMATUNE = int(os.getenv("BST_TIMEOUT_ENIGMATUNE",10))
setting.CUTOFF = int(os.getenv("BST_CUTOFF",1))
setting.MIN_SLOTS = int(os.getenv("BST_MIN_CEFS",1))
setting.SLOTS = int(os.getenv("BST_MAX_CEFS",6))
setting.CORES = int(os.getenv("CORES",4))

EVAL_LIMIT = int(os.getenv("BST_EVAL_LIMIT",1))

setting.ITERS = 2
setting.PROBLEMS = "200"
setting.INSTANCE_FILE = "data/problems.txt"

CEFS = {
   "ClauseWeightAge(ByCreationDate,7,50,2,3)": 2, 
   "ClauseWeightAge(ByNegLitDist,1,10,2,5)": 1, 
   "ClauseWeightAge(ByNegLitDist,200,5,0.5,0.8)": 1, 
   "ClauseWeightAge(ByNegLitDist,3,200,0.5,0.1)": 1, 
   "ClauseWeightAge(ConstPrio,1,100,2.5,0.7)": 1, 
   "ClauseWeightAge(ConstPrio,5,-1,0.3,1)": 1, 
   "ClauseWeightAge(ConstPrio,5,300,1,0.5)": 1, 
   "ClauseWeightAge(DeferSOS,0,4,2,9999.9)": 1, 
   "ClauseWeightAge(DeferSOS,1,200,0.5,0.3)": 1, 
   "ClauseWeightAge(DeferSOS,1,50,0.3,1)": 1, 
   "ClauseWeightAge(DeferSOS,5,300,0.5,0.5)": 1, 
   "ClauseWeightAge(PreferGoals,3,50,1,2)": 1, 
   "ClauseWeightAge(PreferNonGoals,-2,18,0.2,4)": 1, 
   "ClauseWeightAge(PreferNonGoals,2,300,1,0.5)": 1, 
   "ClauseWeightAge(PreferNonGoals,4,200,0.8,5)": 1, 
   "ClauseWeightAge(PreferNonGoals,7,200,2,2.5)": 1, 
   "ClauseWeightAge(PreferProcessed,-1,10,0.7,0.8)": 1, 
   "ClauseWeightAge(PreferProcessed,-1,18,0.2,1)": 1, 
   "ClauseWeightAge(PreferProcessed,9999,0,0.8,3)": 1, 
   "ClauseWeightAge(PreferUnitGroundGoals,1,300,2.5,1)": 1, 
   "ClauseWeightAge(PreferUnitGroundGoals,1,300,4,1)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,100,0.1,2.5)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,18,0.2,0.3)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,18,0.2,1)": 27, 
   "ClauseWeightAge(SimulateSOS,-1,18,0.2,3)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,18,0.5,1)": 2, 
   "ClauseWeightAge(SimulateSOS,-1,18,1,3)": 2, 
   "ClauseWeightAge(SimulateSOS,-1,200,0.5,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,50,0.1,1)": 1, 
   "ClauseWeightAge(SimulateSOS,-1,50,0.5,2.5)": 1, 
   "ClauseWeightAge(SimulateSOS,-2,-1,5,1)": 1, 
   "ClauseWeightAge(SimulateSOS,-2,18,0.7,4)": 2, 
   "ClauseWeightAge(SimulateSOS,-2,18,3,0.7)": 1, 
   "ClauseWeightAge(SimulateSOS,-2,7,1,3)": 1, 
   "ClauseWeightAge(SimulateSOS,0,18,0.5,2)": 1, 
   "ClauseWeightAge(SimulateSOS,0,200,4,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,3,20,0.5,1.5)": 1, 
   "ClauseWeightAge(SimulateSOS,3,200,1.5,0.3)": 1, 
   "ClauseWeightAge(SimulateSOS,3,200,3,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,3,400,1.5,2)": 1, 
   "ClauseWeightAge(SimulateSOS,4,200,1,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,5,200,0.5,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,50,200,0.5,0.1)": 1, 
   "ClauseWeightAge(SimulateSOS,7,200,0.5,0.1)": 29, 
   "ClauseWeightAge(SimulateSOS,7,200,0.5,2)": 1, 
   "Clauseweight(ByCreationDate,1,100,9999.9)": 1, 
   "Clauseweight(ByCreationDate,1,200,9999.9)": 1, 
   "Clauseweight(ByCreationDate,20,300,0.7)": 2, 
   "Clauseweight(ByCreationDate,9999,-2,4)": 1, 
   "Clauseweight(ByNegLitDist,300,9999,1.5)": 2, 
   "Clauseweight(ConstPrio,-1,10,9999.9)": 1, 
   "Clauseweight(ConstPrio,-2,9999,5)": 1, 
   "Clauseweight(ConstPrio,0,5,2)": 1, 
   "Clauseweight(ConstPrio,1,1,0.5)": 1, 
   "Clauseweight(ConstPrio,1,1,1)": 1, 
   "Clauseweight(ConstPrio,1,9999,2)": 1, 
   "Clauseweight(ConstPrio,10,200,0.8)": 1, 
   "Clauseweight(ConstPrio,10,3,0.7)": 1, 
   "Clauseweight(ConstPrio,10,9999,5)": 2, 
   "Clauseweight(ConstPrio,5,50,2)": 1, 
   "Clauseweight(DeferSOS,3,2,0.5)": 1, 
   "Clauseweight(PreferGoals,20,1,3)": 1, 
   "Clauseweight(PreferGoals,20,9999,3)": 1, 
   "Clauseweight(PreferGoals,300,9999,1)": 1, 
   "Clauseweight(PreferGroundGoals,0,1,3)": 1, 
   "Clauseweight(PreferGroundGoals,18,300,3)": 1, 
   "Clauseweight(PreferGroundGoals,2,400,1.5)": 1, 
   "Clauseweight(PreferGroundGoals,2,9999,3)": 1, 
   "Clauseweight(PreferGroundGoals,20,7,0.1)": 1, 
   "Clauseweight(PreferGroundGoals,20,7,0.2)": 1, 
   "Clauseweight(PreferGroundGoals,300,300,0.1)": 1, 
   "Clauseweight(PreferGroundGoals,4,300,2)": 1, 
   "Clauseweight(PreferGroundGoals,4,400,5)": 1, 
   "Clauseweight(PreferGroundGoals,5,300,0.2)": 1, 
   "Clauseweight(PreferGroundGoals,5,300,1)": 2, 
   "Clauseweight(PreferGroundGoals,5,9999,5)": 1, 
   "Clauseweight(PreferGroundGoals,7,9999,0.7)": 1, 
   "Clauseweight(PreferNonGoals,1,10,2)": 1, 
   "Clauseweight(PreferNonGoals,1,20,2)": 2, 
   "Clauseweight(PreferNonGoals,2,200,4)": 1, 
   "Clauseweight(PreferNonGoals,20,300,1.5)": 1, 
   "Clauseweight(PreferNonGoals,200,300,9999.9)": 1, 
   "Clauseweight(PreferNonGoals,3,300,1)": 1, 
   "Clauseweight(PreferNonGoals,300,9999,0.2)": 1, 
   "Clauseweight(PreferNonGoals,5,18,9999.9)": 1, 
   "Clauseweight(PreferProcessed,-2,0,2.5)": 1, 
   "Clauseweight(PreferProcessed,-2,200,5)": 3, 
   "Clauseweight(PreferProcessed,-2,5,3)": 1, 
   "Clauseweight(PreferProcessed,-2,9999,5)": 1, 
   "Clauseweight(PreferProcessed,0,1,1)": 1, 
   "Clauseweight(PreferProcessed,0,18,2.5)": 1, 
   "Clauseweight(PreferProcessed,0,300,3)": 1, 
   "Clauseweight(PreferProcessed,1,1,1)": 3, 
   "Clauseweight(PreferProcessed,1,300,3)": 1, 
   "Clauseweight(PreferProcessed,1,50,1)": 1, 
   "Clauseweight(PreferProcessed,1,9999,5)": 1, 
   "Clauseweight(PreferProcessed,18,200,3)": 1, 
   "Clauseweight(PreferProcessed,18,300,3)": 1, 
   "Clauseweight(PreferProcessed,18,300,4)": 2, 
   "Clauseweight(PreferProcessed,18,300,5)": 1, 
   "Clauseweight(PreferProcessed,2,300,3)": 1, 
   "Clauseweight(PreferProcessed,20,300,3)": 52, 
   "Clauseweight(PreferProcessed,3,200,4)": 1, 
   "Clauseweight(PreferProcessed,3,300,3)": 1, 
   "Clauseweight(PreferProcessed,3,50,2)": 1, 
   "Clauseweight(PreferProcessed,4,300,3)": 1, 
   "Clauseweight(PreferProcessed,5,9999,4)": 1, 
   "Clauseweight(PreferProcessed,7,10,0.1)": 1, 
   "Clauseweight(PreferProcessed,7,200,3)": 1, 
   "Clauseweight(PreferProcessed,9999,-1,3)": 2, 
   "Clauseweight(PreferUnitGroundGoals,-2,200,5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,0,200,4)": 1, 
   "Clauseweight(PreferUnitGroundGoals,0,5,3)": 1, 
   "Clauseweight(PreferUnitGroundGoals,0,9999,3)": 2, 
   "Clauseweight(PreferUnitGroundGoals,1,-2,2.5)": 2, 
   "Clauseweight(PreferUnitGroundGoals,1,20,1)": 1, 
   "Clauseweight(PreferUnitGroundGoals,1,9999,0.7)": 1, 
   "Clauseweight(PreferUnitGroundGoals,10,9999,3)": 1, 
   "Clauseweight(PreferUnitGroundGoals,10,9999,5)": 3, 
   "Clauseweight(PreferUnitGroundGoals,2,18,0.5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,2,200,3)": 1, 
   "Clauseweight(PreferUnitGroundGoals,2,200,4)": 1, 
   "Clauseweight(PreferUnitGroundGoals,2,300,0.5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,200,0,0.5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,300,7,4)": 1, 
   "Clauseweight(PreferUnitGroundGoals,4,9999,5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,400,9999,2)": 1, 
   "Clauseweight(PreferUnitGroundGoals,400,9999,3)": 2, 
   "Clauseweight(PreferUnitGroundGoals,400,9999,4)": 1, 
   "Clauseweight(PreferUnitGroundGoals,5,3,0.2)": 1, 
   "Clauseweight(PreferUnitGroundGoals,5,300,3)": 1, 
   "Clauseweight(PreferUnitGroundGoals,5,9999,5)": 1, 
   "Clauseweight(PreferUnitGroundGoals,7,200,1)": 1, 
   "Clauseweight(PreferUnitGroundGoals,7,200,9999.9)": 1, 
   "Clauseweight(PreferUnitGroundGoals,7,9999,2)": 1, 
   "Clauseweight(PreferUnitGroundGoals,7,9999,4)": 1, 
   "Clauseweight(PreferUnitGroundGoals,7,9999,5)": 40, 
   "Clauseweight(SimulateSOS,18,9999,4)": 1, 
   "Clauseweight(SimulateSOS,50,200,2.5)": 1, 
   "Clauseweight(SimulateSOS,7,400,5)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,0,1,18,-1,-2,2,-2,0.2,2,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,20,7,300,0,-1,20,-2,3,1,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,200,300,300,-1,0,3,-2,0.2,0.8,2)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,300,-1,20,-1,1,1,-1,0.3,3,2)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,300,2,300,-1,0,1,-2,0.2,0.5,4)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,300,200,100,3,-2,18,-1,0.1,0.7,0.7)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,300,400,18,-1,1,3,3,3,1.5,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,400,10,5,-2,-2,3,-2,0.3,4,4)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,400,50,1,-1,0,1,-2,0.3,0.8,4)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,400,50,4,-1,1,1,-2,0.3,0.8,4)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,400,9999,200,-1,0,4,1,2,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,50,2,18,-1,0,2,-2,1.5,0.8,2)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,50,7,300,-1,0,0,-2,0.1,0.3,2)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,50,9999,1,-1,0,3,1,3,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,50,9999,200,-1,0,3,1,1.5,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,7,10,7,2,2,7,10,0.2,1.5,2)": 1, 
   "ConjectureGeneralSymbolWeight(ByCreationDate,9999,400,1,-2,0,5,3,4,1,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(ByNegLitDist,-2,400,300,4,-2,4,50,1,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ByNegLitDist,400,18,4,2,3,10,400,1,0.7,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(ByNegLitDist,9999,20,9999,0,7,3,400,0.7,1,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-1,9999,300,10,4,-1,300,1.5,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-2,0,2,18,400,400,0,1,3,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-2,1,-1,4,10,300,50,3,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-2,300,3,0,5,50,50,0.2,3,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-2,9999,7,4,-1,4,50,2,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,-2,9999,9999,7,-1,-1,100,3,0.7,0.3)": 2, 
   "ConjectureGeneralSymbolWeight(ConstPrio,0,100,100,3,2,3,2,3,0.1,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,1,-2,200,3,1,200,400,5,0.1,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,1,100,20,10,-2,1,300,3,0.2,0.3)": 3, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,-2,300,4,-2,4,0,0.5,2.5,3)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,18,10,4,-2,7,0,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,2,9999,10,3,3,-1,1.5,0.2,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,3,300,1,-2,200,18,3,0.1,2.5)": 2, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,3,300,2,7,1,9999,1.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-1,4,50,3,0.2,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,1,50,3,0.2,2.5)": 2, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,2,50,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,20,50,4,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,200,50,3,0.2,2.5)": 25, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,4,-2,4,50,3,0.2,2.5)": 28, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,300,300,5,10,200,50,3,9999.9,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,400,20,5,-2,50,50,0.2,3,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,400,5,4,-2,200,50,3,2,2.5)": 6, 
   "ConjectureGeneralSymbolWeight(ConstPrio,10,50,300,4,-2,4,50,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,100,300,9999,4,-2,-1,5,0.8,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,100,5,9999,-1,2,-2,50,0.7,1,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,2,300,10,4,-2,9999,5,1,3,3)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,2,400,300,0,1,0,7,1.5,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,20,5,400,5,0,2,20,5,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,200,400,2,4,400,9999,300,3,0.8,1)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,200,50,200,18,1,2,50,0.1,4,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,3,2,7,1,-2,-2,3,0.2,0.5,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,3,300,300,-1,10,200,50,2.5,5,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,3,300,300,-1,10,200,50,9999.9,5,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,3,300,300,200,10,200,50,3,9999.9,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,3,9999,3,1,4,400,7,0.2,2,1)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,300,18,10,4,-2,4,50,2.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,300,400,-2,5,0,2,50,1,0.2,1)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,4,10,200,3,-2,1,50,0.7,4,2)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,4,400,300,5,1,4,50,4,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,4,5,200,3,-2,4,200,1,0.1,0.7)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,400,18,300,5,18,300,100,0.1,3,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,400,20,18,1,5,10,400,0.1,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,400,300,200,4,-2,200,50,3,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,400,9999,9999,7,-2,0,100,0.3,1.5,5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,50,7,300,4,2,400,50,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,7,10,20,20,10,0,-2,0.5,0.5,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,7,2,0,300,-1,2,9999,9999.9,2.5,4)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,7,3,5,4,2,1,9999,9999.9,2.5,4)": 3, 
   "ConjectureGeneralSymbolWeight(ConstPrio,7,300,300,-1,0,4,50,2,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(ConstPrio,7,9999,5,2,20,-1,400,4,0.1,4)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,18,200,-1,1,-1,50,50,1,4,4)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,18,9999,9999,-1,0,20,200,0.2,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,2,1,9999,2,1,5,-2,2,0.1,1.5)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,2,100,-2,-2,50,0,400,3,0.2,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,2,300,400,18,10,3,10,1,0.1,2)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,200,5,200,-1,0,2,-2,0.8,0.8,3)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,5,100,300,18,2,100,400,4,0.5,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(DeferSOS,9999,5,1,4,3,300,9999,4,2.5,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,-1,9999,400,3,2,-2,100,3,0.2,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,-1,9999,400,3,2,5,100,3,0.2,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,0,9999,400,3,2,18,100,3,0.2,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,1,9999,400,3,2,10,100,4,0.1,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,1,9999,400,4,-2,100,100,3,0.2,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,10,300,300,4,-2,4,50,3,0.7,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,2,1,7,300,18,300,400,1,2,0.7)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,2,300,1,1,4,7,50,4,4,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,20,400,4,5,0,2,50,1,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,5,300,300,4,-2,4,50,1.5,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,5,5,300,3,2,50,4,1,2.5,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,50,400,1,-2,18,1,9999,5,4,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,50,9999,-1,4,0,-2,50,4,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,9999,3,3,200,-2,2,-1,2,0.7,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,9999,300,9999,0,7,200,400,2.5,1,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGoals,9999,300,9999,2,7,4,400,2.5,1,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,-2,4,100,3,-2,20,50,1,4,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,1,1,400,-1,-1,50,3,1.5,3,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,1,100,100,4,-2,4,-1,1.5,3,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,10,0,300,4,-2,4,50,4,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,10,300,300,5,-1,400,50,2,0.1,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,10,5,200,4,3,-1,50,3,0.2,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,100,2,5,1,5,20,200,2.5,0.3,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,100,3,1,4,0,-2,50,2,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,18,200,300,3,-2,2,50,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,18,4,9999,1,0,-2,50,0.1,5,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,2,18,9999,3,100,400,400,1,3,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,3,10,9999,0,0,0,4,0.1,5,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,3,20,100,2,100,-2,-2,0.3,2.5,2.5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,3,200,9999,5,0,0,7,0.3,3,1.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,3,3,7,1,-2,0,4,0.2,0.5,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,3,400,9999,4,0,0,10,0.3,5,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,5,3,-1,0,10,0,400,3,5,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,7,200,9999,5,0,-2,4,0.3,2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,9999,10,5,-2,18,100,400,5,5,0.7)": 1, 
   "ConjectureGeneralSymbolWeight(PreferGroundGoals,9999,400,9999,-1,2,20,400,4,0.7,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,-1,20,7,400,1,-2,9999,5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,-1,5,300,-1,-2,10,10,0.2,5,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,-2,100,300,3,-2,4,4,2.5,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,10,100,300,3,-2,4,4,2,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,10,2,10,1,7,-2,9999,2.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,10,3,9999,300,100,20,400,1,3,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,10,50,9999,7,-1,-2,300,0.1,1,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,100,200,50,50,1,100,1.5,1.5,2.5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,20,9999,1,-2,0,4,0.7,2.5,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,300,200,50,50,-2,50,5,4,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,9999,0,2,0,18,18,0.7,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,9999,300,2,3,-1,50,2,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,9999,400,2,3,18,18,2,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,100,9999,400,4,3,18,0,2,0.2,3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,-2,50,3,100,1,1.5,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,5,1,100,1.5,1.5,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,50,1.5,4,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,7,2,50,-2,200,1.5,1.5,1.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,200,50,200,5,10,3,100,2,1,1)": 2, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,3,300,100,4,-2,100,100,0.2,0.3,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,300,100,200,50,-2,-2,100,0.7,1.5,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,300,200,200,20,-2,-2,50,0.7,1,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,400,10,200,5,-2,10,4,2,3,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,400,200,300,-2,4,2,400,0.1,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,5,100,300,4,-2,200,50,3,1,0.7)": 2, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,5,100,300,4,-2,7,50,3,1,0.7)": 2, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,5,100,300,4,-2,7,50,5,1,0.7)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,50,2,18,0,2,10,7,1.5,0.5,4)": 1, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,7,200,1,-2,2,20,18,9999.9,1,0.7)": 2, 
   "ConjectureGeneralSymbolWeight(PreferNonGoals,9999,50,20,0,2,10,7,1,0.5,2)": 3, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,-2,100,7,4,0,5,200,0.1,9999.9,4)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,-2,20,7,0,10,200,50,9999.9,0.2,1.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,0,0,200,5,0,50,50,0.2,0.2,1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,10,-2,300,4,-2,0,20,2.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,10,9999,9999,4,-1,2,50,3,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,300,400,3,-2,4,4,3,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,300,400,4,-2,3,4,3,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,300,50,4,-2,-2,50,3,0.2,4)": 3, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,400,4,-2,2,4,3,0.2,5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,1,-2,1,5,1,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,4,-2,3,5,1,0.2,2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,4,-2,3,5,1,0.2,5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,100,9999,9999,4,-2,3,5,4,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,18,0,10,-1,0,100,20,2,0.3,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,18,9999,5,4,0,3,50,3,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,2,400,300,4,-2,7,50,2.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,2,7,400,4,-2,7,50,2.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,20,9999,2,4,0,2,50,1,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,300,50,7,-1,-1,50,1,0.7,2,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,300,7,200,20,4,20,50,1,0.1,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,400,50,400,-1,-1,50,2,2,2,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,400,9999,9999,5,-2,2,100,0.7,1.5,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,50,20,4,7,4,400,50,1,0.1,0.1)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,50,50,400,0,-1,7,-2,1,2.5,2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,7,-2,300,200,4,1,50,0.7,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,7,300,300,1,5,2,50,0.7,0.2,2.5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,7,400,300,1,7,7,50,0.7,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferProcessed,9999,400,7,20,200,50,300,2,0.2,2)": 2, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,-2,300,300,2,-2,4,50,4,0.8,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,10,0,9999,0,0,-2,50,0.1,3,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,10,300,300,4,7,0,50,1.5,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,100,400,-2,18,0,3,50,2.5,0.2,4)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,100,9999,9999,4,-2,3,5,0.8,0.2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,18,200,300,3,-2,-1,50,3,0.2,2.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,18,4,9999,0,0,-2,50,0.1,5,0.8)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,18,400,1,0,5,3,50,0.5,3,9999.9)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,2,400,-2,-1,4,50,50,3,2,4)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,20,400,7,3,-2,-2,7,1,0.3,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,20,400,7,4,-2,-2,7,1,0.2,0.3)": 2, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,200,9999,200,18,1,2,50,0.2,1.5,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,3,4,9999,0,0,0,7,0.1,5,1.5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,300,-2,-1,300,18,18,50,0.3,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,4,9999,300,3,3,7,10,0.2,0.2,1.5)": 2, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,400,50,400,-1,-1,50,2,0.8,2,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,50,10,50,2,-1,20,2,2,1.5,2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,7,300,300,0,-2,200,20,4,0.3,0.2)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,9999,300,20,0,4,7,400,0.8,0.8,0.3)": 1, 
   "ConjectureGeneralSymbolWeight(PreferUnitGroundGoals,9999,7,400,-1,-1,400,2,3,2,0.5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,0,100,3,-1,20,1,300,2.5,4,2)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,10,100,5,20,-2,200,50,3,1,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,-2,5,3,1,18,50,1.5,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,400,-1,50,1,7,50,1,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,400,-2,0,4,2,50,2,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,400,1,3,4,18,50,2.5,2,5)": 16, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,400,1,3,4,7,50,2.5,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,2,9999,1,3,3,18,9999,2.5,2,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,200,400,10,10,7,4,-1,0.5,1,9999.9)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,300,400,100,10,20,20,2,2,1,5)": 2, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,400,400,100,3,1,20,3,0.8,1,5)": 1, 
   "ConjectureGeneralSymbolWeight(SimulateSOS,5,20,-1,5,7,10,18,1.5,0.1,2)": 1, 
   "ConjectureLevDistanceWeight(ByCreationDate,0,0,2,10,10,0,1.5,1,1.5)": 1, 
   "ConjectureLevDistanceWeight(ByCreationDate,1,0,50,9999,1,0,0.2,4,0.7)": 1, 
   "ConjectureLevDistanceWeight(ByNegLitDist,0,1,50,200,100,0,0.7,0.8,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,0,0,10,9999,3,0,0.5,1,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,10,100,3,0,2,1.5,1)": 2, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,10,300,3,0,0.8,2,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,10,300,3,0,2,1.5,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,10,9999,3,0,0.8,2,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,100,18,3,0,1,1.5,1)": 2, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,2,10,1,0,5,3,1.5)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,20,18,3,0,3,1.5,1)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,50,18,4,0,4,1.5,1.5)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,50,20,4,0,4,2,0.8)": 1, 
   "ConjectureLevDistanceWeight(ConstPrio,1,0,50,20,7,0,0.8,1.5,2)": 1, 
   "ConjectureLevDistanceWeight(DeferSOS,0,0,300,100,7,0,4,2.5,9999.9)": 1, 
   "ConjectureLevDistanceWeight(DeferSOS,1,0,300,18,10,0,0.8,2,1.5)": 1, 
   "ConjectureLevDistanceWeight(DeferSOS,1,0,300,400,2,0,3,0.7,9999.9)": 1, 
   "ConjectureLevDistanceWeight(DeferSOS,1,0,9999,9999,3,0,0.1,2,9999.9)": 1, 
   "ConjectureLevDistanceWeight(DeferSOS,1,0,9999,9999,4,0,0.7,3,9999.9)": 1, 
   "ConjectureLevDistanceWeight(PreferGoals,1,0,300,18,0,0,2,4,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferGroundGoals,0,0,10,9999,3,0,0.5,0.8,0.8)": 1, 
   "ConjectureLevDistanceWeight(PreferGroundGoals,1,0,300,18,10,0,2.5,1,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferGroundGoals,1,2,100,200,20,1,4,2.5,3)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,10,10,0,1,0.5,1)": 2, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,10,10,0,1,0.5,3)": 3, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,20,10,0,0.1,2,2.5)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,10,300,5,0,1,0.5,3)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,20,300,4,0,2.5,0.8,3)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,4,18,50,0,0.1,0.1,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,0,400,18,5,0,2.5,1.5,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,1,100,18,5,0,2.5,9999.9,2)": 1, 
   "ConjectureLevDistanceWeight(PreferNonGoals,1,2,9999,300,100,0,0.5,0.2,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferProcessed,1,0,-1,5,4,0,2.5,0.3,0.1)": 1, 
   "ConjectureLevDistanceWeight(PreferProcessed,1,0,50,18,5,0,1.5,1.5,1.5)": 1, 
   "ConjectureLevDistanceWeight(PreferProcessed,1,0,50,18,5,0,2,1.5,3)": 2, 
   "ConjectureLevDistanceWeight(PreferProcessed,1,0,50,18,5,0,4,1.5,3)": 1, 
   "ConjectureLevDistanceWeight(PreferProcessed,1,2,200,18,2,2,4,0.2,0.1)": 1, 
   "ConjectureLevDistanceWeight(PreferUnitGroundGoals,0,0,7,400,3,0,0.3,0.8,0.7)": 1, 
   "ConjectureLevDistanceWeight(PreferUnitGroundGoals,1,0,5,400,4,0,2.5,0.8,3)": 1, 
   "ConjectureLevDistanceWeight(PreferUnitGroundGoals,1,3,10,18,4,2,4,4,0.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,0,0,50,18,3,0,4,0.3,1.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,0,2,400,-1,20,2,2,0.8,4)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,0,3,7,300,400,0,0.5,1,2.5)": 2, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,-1,4,10,0,4,3,1.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,20,18,5,0,2,1.5,1.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,3,18,1,0,2,1.5,1.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,300,20,3,0,1,4,1)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,5,18,5,0,2,1.5,2)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,50,100,-1,0,2.5,0.1,0.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,50,18,5,0,0.2,4,3)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,50,18,5,0,2,1.5,1.5)": 23, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,50,400,5,0,2,1.5,3)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,0,50,9999,-2,0,2.5,0.3,2)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,2,18,3,10,0,3,1,0.2)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,2,18,300,4,0,9999.9,0.2,1.5)": 1, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,2,300,300,5,0,9999.9,0.2,0.7)": 2, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,2,400,200,4,0,9999.9,0.2,0.7)": 2, 
   "ConjectureLevDistanceWeight(SimulateSOS,1,2,9999,200,4,0,9999.9,0.2,1.5)": 25, 
   "ConjectureRelativeSymbolWeight(ByCreationDate,0.1,200,18,100,10,5,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(ByNegLitDist,0.1,100,100,400,2,1,3,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(ByNegLitDist,0.1,18,5,0,200,5,4,4)": 1, 
   "ConjectureRelativeSymbolWeight(ByNegLitDist,0.1,20,4,18,200,4,2.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ByNegLitDist,0.1,3,7,50,100,2,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ByNegLitDist,0.7,100,-1,9999,100,5,5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,-1,400,2,1,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,-2,100,100,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,-2,18,100,0.2,4,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,0,20,5,4,9999.9,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,1,100,-1,2,5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,1,100,100,4,0.5,0.7)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,1,50,5,2,9999.9,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,-2,4,4,0.8)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,-2,4,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.2,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.2,3,1.5)": 4, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.3,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.3,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.5,1,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.5,1.5,1.5)": 3, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.7,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,0.8,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,0.7,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,1,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,1.5,0.7)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,1.5,1.5)": 30, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,1.5,2.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,2,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,100,2.5,1,0.7)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,100,2,2.5,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,200,-2,0.2,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,200,2,2.5,4,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,400,100,0.3,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,100,50,100,2.5,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,18,200,100,3,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,2,100,100,2,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,2,100,100,3,1.5,0.8)": 4, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,2,100,100,9999.9,0.5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,20,100,100,4,0.7,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,3,100,-1,1.5,5,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,3,100,100,1.5,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,3,200,100,5,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,4,100,100,3,1,1.5)": 3, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,4,50,9999,2.5,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,5,4,100,0.2,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,50,100,100,1.5,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,50,50,20,0.8,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,7,100,100,2,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,7,100,100,4,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,7,100,20,0.3,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,100,7,400,2,1,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,18,300,100,200,1.5,1.5,4)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,2,4,5,1,0.5,0.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,20,300,9999,20,5,0.8,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,20,300,9999,20,5,0.8,1)": 3, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,200,300,100,200,1.5,1.5,4)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,3,5,20,1,0.8,0.2,0.2)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,400,2,100,100,5,1,0.7)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,50,100,200,0,1.5,0.5,1)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,50,100,200,0,2,0.7,1)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,50,100,400,20,1.5,0.8,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,7,100,-2,100,0.2,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.1,7,50,100,100,2.5,1,0.2)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.2,20,300,9999,50,5,0.8,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.2,5,20,400,100,1.5,2.5,3)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.3,100,1,100,100,4,1,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.3,100,100,100,100,2.5,1,1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.3,100,100,300,3,0.8,3,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.3,50,100,100,100,5,0.2,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.7,100,100,100,100,2,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(ConstPrio,0.7,7,5,20,-2,0.5,0.5,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(ConstPrio,9999.9,10,9999,3,1,2,0.8,9999.9)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,1,7,0,200,3,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,100,1,3,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,100,2,2.5,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,100,20,1,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,20,2,0.2,1.5,1.5)": 5, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,20,2,0.3,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,20,7,0.2,0.1,2)": 2, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,200,20,2.5,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,400,20,1,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,100,400,20,4,0.5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,100,9999,100,50,1,4,2)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,20,5,18,200,1.5,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,50,100,400,20,5,0.5,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,50,200,400,18,0.8,2.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.1,7,5,50,100,2,1,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.3,300,100,-2,100,2.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.3,300,100,100,100,2.5,1.5,1)": 2, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.5,1,2,3,50,2.5,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,0.5,300,7,18,50,0.8,0.8,2)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,1,50,20,20,50,1.5,2.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,1.5,4,3,0,10,2.5,0.3,9999.9)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,1.5,4,3,1,10,0.8,0.3,9999.9)": 2, 
   "ConjectureRelativeSymbolWeight(DeferSOS,2.5,50,100,10,100,3,2.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,4,10,9999,5,-2,1.5,3,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(DeferSOS,4,100,-1,5,1,2,0.2,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGoals,0.1,100,100,400,100,0.5,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGoals,0.1,20,7,50,200,1,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGoals,0.1,9999,10,1,2,0.3,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,-1,100,400,2,1,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,0,400,5,3,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,1,200,100,9999.9,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,-2,20,1.5,2,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,10,2.5,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,100,3,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1,1,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1.5,1,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1.5,1.5,1.5)": 49, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,20,1.5,1.5,5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,5,3,1,3)": 3, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,7,2,0.3,3)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,7,3,0.3,3)": 4, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,7,3,1,3)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,100,7,3,1.5,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,200,2,4,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,300,100,0.2,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,0,4,3,0.2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,1,1,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,100,0.3,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,2,1,1,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,2,1,3,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,2,1,3,0.8)": 37, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,2,1,3,1)": 5, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,5,1.5,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,100,400,50,4,2,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,20,100,200,0.2,0.3,5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,20,400,2,1,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,200,100,10,0.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,300,400,18,4,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,5,100,20,0.3,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,5,100,20,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,100,50,100,100,1,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,18,5,20,200,4,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,18,50,200,18,2,1,4)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,2,100,300,10,0.3,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,3,1,50,2,3,0.3,0.8)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,300,50,300,100,5,1.5,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,4,300,50,0,1,2,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,100,400,100,1,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,100,400,20,1.5,0.8,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,18,7,20,1,1.5,4)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,200,400,4,2.5,2.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.1,50,300,50,7,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,1,10,-1,100,4,0.5,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,100,1,100,2,1,2,5)": 4, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,100,1,400,2,1,1.5,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,100,100,200,100,0.1,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,18,5,200,300,3,2.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,20,300,9999,-2,5,0.8,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,50,100,100,18,1.5,4,0.2)": 3, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.2,50,100,400,20,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,0.3,100,200,100,20,2,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,1,-1,200,400,20,0.2,3,0.2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,1,100,-2,100,100,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,2,10,-1,300,20,0.2,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,2,10,-1,300,200,0.2,1.5,2)": 2, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,2,4,-2,100,200,9999.9,3,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,2,7,-2,300,200,9999.9,2,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferGroundGoals,3,18,200,50,50,0.3,0.8,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,1,100,100,0,0.2,5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,0,100,100,2,0.7,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,10,100,100,4,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,10,200,100,5,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,0.2,5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,0.8,5,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,1,5,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,1.5,5,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,1.5,5,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-1,1.5,5,1)": 39, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-2,1,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-2,3,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,-2,4,4,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,100,0.7,1,1)": 2, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,100,0.8,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,100,100,1.5,1.5,0.8)": 3, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,5,50,3,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,9999,400,5,4,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,100,9999,400,5,5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,2,100,100,2,1.5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,2,100,100,2,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,2,100,100,3,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,20,100,18,0.7,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,20,9999,400,9999.9,4,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,200,100,20,0.5,9999.9,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,3,100,100,2.5,0.3,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,400,5,-2,0.3,2,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,50,20,18,0.1,1.5,1.5)": 4, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,50,400,100,1,0.8,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,50,400,100,4,0.8,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,100,7,50,-1,1.5,2.5,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,50,100,300,0,1,0.1,0.1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.1,50,200,400,20,1.5,0.7,0.2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.3,100,100,100,2,1.5,5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,0,4,20,100,2,4,2.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,10,2,3,20,9999.9,1,5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,10,200,100,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,-1,20,2.5,2.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,100,1.5,1.5,1)": 13, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,100,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,100,4,1.5,1)": 2, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,20,2.5,1.5,1)": 5, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,100,100,20,2.5,2.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,20,20,100,2.5,1,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,5,200,100,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,100,7,100,100,2.5,1.5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,400,20,2,5,0.1,0.5,2)": 2, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,0.5,400,4,100,9999,5,4,2.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,1,100,4,100,100,2,0.7,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,1,100,4,100,100,2.5,0.7,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,2,100,200,300,7,0.2,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,2,3,1,50,300,3,0.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferNonGoals,2,3,5,50,300,3,0.5,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,1,4,1,3,5,2,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,10,18,4,100,0.1,5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,100,-1,20,0.8,2,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,100,100,-2,4,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,100,100,1,2,1,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,100,100,100,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,20,300,100,3,1.5,2)": 2, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,100,4,300,100,2,3,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,18,10,10,100,0.3,3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,20,10,400,100,2,5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,300,100,-1,20,2,0.2,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.1,5,3,4,200,3,2,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.3,200,5,20,1,0.5,2,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,0.3,300,10,20,1,5,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,4,-1,0,200,10,3,0.3,5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,4,3,20,-2,1,0.5,5,4)": 1, 
   "ConjectureRelativeSymbolWeight(PreferProcessed,5,-2,3,9999,18,0.7,0.2,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,-1,100,7,100,0.2,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,-2,100,400,100,1,1.5,1.5)": 3, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,0,400,100,9999.9,2,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,10,200,100,9999.9,1.5,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,1,100,4,0.7,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,100,100,0.3,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,100,100,1.5,1.5,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,200,100,0.2,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,200,100,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,200,100,1.5,1.5,2)": 2, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,400,100,3,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,100,400,200,5,1.5,2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,2,100,100,0.3,3,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,20,100,-1,1.5,5,1)": 2, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,3,400,100,9999.9,2,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,4,200,100,3,0.8,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,5,100,100,3,1,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,5,400,100,9999.9,2,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,100,7,50,9999,2.5,1,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,2,100,4,100,0.2,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,2,300,300,200,2,1.5,4)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,3,1,50,1,0.2,0.3,1)": 2, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,5,100,4,100,0.2,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,5,7,5,1,1.5,4,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,50,100,200,100,3,1.5,1.5)": 2, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,50,100,400,100,1,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,50,200,400,20,1,0.7,0.7)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.1,50,300,300,200,2,4,4)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.2,100,18,200,10,4,0.3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.2,100,7,200,10,4,0.3,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.3,100,400,7,-2,5,2,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.7,7,5,10,-2,0.5,0.5,0.2)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,0.8,-2,10,400,200,9999.9,2,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,1,300,0,1,7,0.2,2.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,1,4,-2,7,18,0.3,0.2,3)": 1, 
   "ConjectureRelativeSymbolWeight(PreferUnitGroundGoals,2,3,18,3,300,3,0.7,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,0,0,100,50,4,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,100,100,100,100,1.5,1.5,1.5)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,100,100,100,2,4,3,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,100,100,100,7,3,1,3)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,100,18,400,-1,1.5,4,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,200,100,400,5,1.5,2,0.8)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.1,50,100,100,100,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.3,100,100,100,100,1,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.3,100,100,100,200,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.3,100,100,7,200,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.3,50,50,3,400,2,0.7,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.5,10,20,3,100,4,0.7,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.5,100,100,100,100,1.5,1.5,1)": 7, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.5,100,100,100,100,5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.5,100,2,100,100,5,1.5,0.5)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.5,100,20,1,100,1.5,1,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,0.7,100,1,7,100,1.5,1.5,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,1,0,-1,200,4,0.2,0.3,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,1,1,2,0,100,3,0.2,0.3)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,1,50,10,18,7,3,0.7,2)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,3,5,7,3,100,1,0.1,1)": 1, 
   "ConjectureRelativeSymbolWeight(SimulateSOS,4,0,0,-2,-1,3,3,2)": 1, 
   "ConjectureRelativeTermWeight(ByNegLitDist,0,0,0.1,100,9999,100,18,1,9999.9,2,0.7)": 2, 
   "ConjectureRelativeTermWeight(ByNegLitDist,0,1,0.2,20,0,50,1,1,0.1,3,2)": 3, 
   "ConjectureRelativeTermWeight(ByNegLitDist,0,3,0.1,100,9999,100,-1,1,0.7,2.5,0.5)": 1, 
   "ConjectureRelativeTermWeight(ByNegLitDist,0,3,2.5,2,1,200,-1,1,4,0.7,0.3)": 2, 
   "ConjectureRelativeTermWeight(ConstPrio,0,0,1,200,10,10,7,1,1.5,3,5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,1,0.1,18,10,50,50,1,9999.9,4,2)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,1,0.1,18,100,50,50,1,9999.9,4,2.5)": 28, 
   "ConjectureRelativeTermWeight(ConstPrio,0,1,0.1,18,9999,50,50,1,9999.9,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,1,0.5,20,0,0,50,1,9999.9,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,1,2.5,0,-2,1,7,1,0.3,0.5,1)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,2,0.1,50,10,50,300,1,5,0.5,1.5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,0,3,0.1,18,-1,400,20,2,2,3,1)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,0,0.1,100,300,18,3,1,4,2,0.7)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,0,0.1,18,100,50,50,1,9999.9,4,2.5)": 2, 
   "ConjectureRelativeTermWeight(ConstPrio,1,0,0.1,18,200,50,50,1,9999.9,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,0,0.1,5,7,5,4,1,4,1,0.8)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,100,9999,100,3,1,9999.9,2,0.7)": 26, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,18,-2,50,50,1,9999.9,0.8,3)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,18,100,50,50,1,9999.9,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,3,2,100,2,1,2.5,1,3)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,3,200,50,50,1,5,4,2)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,4,9999,-2,100,1,9999.9,2,1)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,400,9999,18,2,1,2,0.3,0.7)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,400,9999,5,200,1,0.3,9999.9,0.5)": 8, 
   "ConjectureRelativeTermWeight(ConstPrio,1,1,0.1,7,-1,100,18,1,0.7,3,0.2)": 1, 
   "ConjectureRelativeTermWeight(ConstPrio,1,3,0.1,100,9999,300,20,1,0.8,2,4)": 2, 
   "ConjectureRelativeTermWeight(ConstPrio,1,3,0.1,100,9999,400,20,1,0.8,2,4)": 1, 
   "ConjectureRelativeTermWeight(DeferSOS,1,1,0.1,3,100,10,400,1,1.5,4,3)": 1, 
   "ConjectureRelativeTermWeight(DeferSOS,1,3,0.2,18,100,300,0,1,1.5,0.1,0.1)": 2, 
   "ConjectureRelativeTermWeight(DeferSOS,1,3,0.2,18,20,2,0,1,4,0.1,0.1)": 1, 
   "ConjectureRelativeTermWeight(DeferSOS,1,3,0.2,18,20,3,0,1,4,0.1,0.1)": 6, 
   "ConjectureRelativeTermWeight(DeferSOS,1,3,0.2,18,20,7,0,1,4,0.1,0.1)": 2, 
   "ConjectureRelativeTermWeight(DeferSOS,1,3,0.2,18,7,-2,0,1,2,0.1,0.1)": 3, 
   "ConjectureRelativeTermWeight(PreferGoals,0,0,0.1,1,-2,9999,100,0,1,2.5,5)": 1, 
   "ConjectureRelativeTermWeight(PreferGoals,0,1,3,2,100,100,50,1,1,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(PreferGoals,1,1,0.1,18,2,3,300,1,9999.9,4,2.5)": 1, 
   "ConjectureRelativeTermWeight(PreferGoals,1,2,4,5,300,20,400,2,2,0.3,0.2)": 1, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,0,0,0.1,100,9999,100,18,1,9999.9,4,0.7)": 1, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,0,3,0.1,18,-2,18,-1,1,0.2,2,0.8)": 2, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,0,3,0.1,20,-1,3,200,1,2.5,3,2)": 1, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,1,0,0.5,1,300,50,50,1,4,2,1.5)": 1, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,1,1,1,-2,400,400,1,1,3,4,1)": 1, 
   "ConjectureRelativeTermWeight(PreferGroundGoals,1,3,0.2,10,20,-2,0,1,2,0.1,0.1)": 1, 
   "ConjectureRelativeTermWeight(PreferNonGoals,0,0,0.1,100,100,1,3,1,9999.9,1,0.7)": 1, 
   "ConjectureRelativeTermWeight(PreferNonGoals,0,1,0.1,10,200,2,50,1,0.5,2,5)": 1, 
   "ConjectureRelativeTermWeight(PreferNonGoals,0,1,0.1,18,100,50,50,1,2,2,2.5)": 6, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,0,0.1,10,100,50,50,1,2.5,2,2)": 4, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,0,0.1,10,200,100,400,1,5,3,3)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,0,0.1,10,400,100,300,1,5,3,2.5)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,0,0.1,10,400,100,400,1,5,3,2)": 8, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,0,0.1,20,400,100,400,1,0.1,2,3)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,1,0.1,10,7,50,50,1,3,2,2)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,0,1,0.2,10,100,50,50,1,4,2,2)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,1,0.1,10,100,50,50,1,3,2,2)": 25, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,1,0.1,50,100,100,3,1,1,2,0.7)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,1,0.2,4,5,50,300,1,9999.9,0.8,3)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,2,0.3,0,-2,50,1,2,2,4,0.1)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,3,0.1,100,400,300,0,1,1.5,2,0.2)": 3, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,3,0.1,200,9999,100,18,1,9999.9,1,0.7)": 1, 
   "ConjectureRelativeTermWeight(PreferProcessed,1,3,0.1,200,9999,100,20,1,9999.9,1,0.7)": 7, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,0,1,0.1,7,100,50,50,1,9999.9,2.5,2.5)": 1, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,0,1,0.3,10,100,50,50,1,5,2,2)": 6, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,0,1,0.3,7,1,400,50,1,9999.9,2,2)": 1, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,0,2,0.3,10,100,50,50,1,5,2,2)": 1, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,1,1,0.1,10,100,200,50,1,2,0.3,2)": 1, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,1,1,0.2,50,18,100,200,1,1,1,2)": 4, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,1,2,0.1,10,300,200,50,1,1,2,0.7)": 7, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,1,3,0.1,100,9999,300,20,1,0.8,2,4)": 11, 
   "ConjectureRelativeTermWeight(PreferUnitGroundGoals,1,3,0.1,100,9999,300,20,1,3,2,4)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,0,0.1,100,9999,100,2,1,0.2,4,0.7)": 4, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,0,0.7,3,9999,100,10,1,4,0.7,0.5)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,2,0.2,10,100,50,50,1,9999.9,2,2)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,2,0.8,-2,20,10,10,1,0.7,0.8,1)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,3,1,20,300,50,300,2,1.5,5,0.7)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,0,3,2,0,18,1,9999,1,0.8,4,0.5)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,0,0.1,1,9999,100,100,1,1.5,9999.9,0.5)": 5, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,0,0.1,1,9999,100,100,1,4,9999.9,0.1)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,0,0.1,20,300,1,200,1,9999.9,0.1,2.5)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,0,0.5,1,300,3,4,1,0.8,1.5,0.3)": 2, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,0,0.5,100,300,50,300,1,3,2,0.2)": 3, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,1,0.2,3,-1,400,1,1,0.7,4,4)": 1, 
   "ConjectureRelativeTermWeight(SimulateSOS,1,2,0.5,1,300,3,4,1,0.8,1.5,0.3)": 1, 
   "ConjectureStrucDistanceWeight(ByCreationDate,1,0,9999.9,5,100,100,1,0.2,1,3)": 1, 
   "ConjectureStrucDistanceWeight(ByNegLitDist,0,2,0.5,0.5,1,10,2,1.5,1.5,0.5)": 1, 
   "ConjectureStrucDistanceWeight(ConstPrio,0,1,0,10,1,100,1,3,2,0.2)": 1, 
   "ConjectureStrucDistanceWeight(ConstPrio,0,1,0,10,1,100,1,4,2,1)": 19, 
   "ConjectureStrucDistanceWeight(ConstPrio,0,1,1,10,1,100,1,3,2,0.2)": 1, 
   "ConjectureStrucDistanceWeight(ConstPrio,0,1,5,10,1,100,2,1.5,2,0.2)": 2, 
   "ConjectureStrucDistanceWeight(ConstPrio,0,1,5,10,5,100,1,1.5,2,1)": 1, 
   "ConjectureStrucDistanceWeight(ConstPrio,1,2,9999.9,10,1,0.1,2,4,2,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferGoals,0,1,0,9999.9,5,9999.9,1,2,2,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferGoals,0,2,0.1,9999.9,100,5,1,4,3,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,0,0,100,1,5,100,0,0.7,2.5,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,0,1,100,10,1,100,1,3,2,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,1,100,1,5,0,2.5,1,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,1,100,1,5,0,3,1,1)": 2, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,100,1,1,100,0,0.7,2.5,1)": 3, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,100,1,1,100,0,0.7,4,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,100,1,1,100,0,1,4,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferGroundGoals,1,0,100,1,1,100,0,3,2.5,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,1,0.1,10,1,100,1,5,1.5,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,1,0.5,10,1,100,1,4,2,2)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,1,5,0,1,0.1,2,0.8,0.1,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,0,0.5,1,0.1,2,9999.9,2,0.8)": 16, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,10,0.5,0.5,0.1,2,2,2,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,10,0.5,1,0.1,2,0.5,2,1)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,100,0.5,1,0.1,2,3,2,0.5)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,5,0.5,1,0.1,2,4,3,0.5)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,0,2,5,100,0.5,1,2,0.2,2,3)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,1,0,9999.9,0.5,0.1,0,1,4,0.2,4)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,1,0,9999.9,5,1,0,0,3,1,4)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,1,1,9999.9,0.5,10,0.5,1,0.7,5,0.1)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,1,2,0.1,0.1,9999.9,0,2,1,3,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferNonGoals,1,3,0.5,0.5,0.5,0.1,2,2,1,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferProcessed,0,1,0.1,100,0.1,9999.9,2,4,0.3,4)": 1, 
   "ConjectureStrucDistanceWeight(PreferProcessed,0,2,0.1,0.5,9999.9,0.1,2,2.5,4,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferProcessed,0,2,100,0.5,1,0.1,2,3,2,0.8)": 1, 
   "ConjectureStrucDistanceWeight(PreferProcessed,1,1,9999.9,100,0.1,9999.9,0,2,0.3,0.1)": 1, 
   "ConjectureStrucDistanceWeight(PreferProcessed,1,3,5,1,0.5,0.1,2,0.7,0.2,2.5)": 1, 
   "ConjectureStrucDistanceWeight(PreferUnitGroundGoals,1,0,0.5,0.1,0.5,0.5,1,3,3,2.5)": 1, 
   "ConjectureStrucDistanceWeight(PreferUnitGroundGoals,1,2,10,10,1,100,1,3,4,1)": 2, 
   "ConjectureStrucDistanceWeight(PreferUnitGroundGoals,1,3,5,0.5,0,9999.9,1,0.1,2.5,2.5)": 1, 
   "ConjectureStrucDistanceWeight(SimulateSOS,1,3,5,1,9999.9,0.5,1,5,3,2.5)": 1, 
   "ConjectureSymbolWeight(ByNegLitDist,0,-1,0,20,2,0.7,0.7,2.5)": 1, 
   "ConjectureSymbolWeight(ByNegLitDist,100,1,4,-2,300,4,2,0.5)": 1, 
   "ConjectureSymbolWeight(ByNegLitDist,18,300,-2,7,1,1.5,2,3)": 1, 
   "ConjectureSymbolWeight(ByNegLitDist,18,300,-2,7,1,1.5,2,4)": 1, 
   "ConjectureSymbolWeight(ByNegLitDist,18,300,-2,7,1,2,0.5,3)": 3, 
   "ConjectureSymbolWeight(ConstPrio,-1,7,10,50,50,2,3,0.3)": 2, 
   "ConjectureSymbolWeight(ConstPrio,200,1,10,50,20,1,3,0.3)": 4, 
   "ConjectureSymbolWeight(ConstPrio,200,18,7,3,300,0.1,1,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,20,10,3,400,0.3,3,4)": 2, 
   "ConjectureSymbolWeight(ConstPrio,200,300,-1,200,50,1,0.3,0.8)": 3, 
   "ConjectureSymbolWeight(ConstPrio,200,300,7,10,10,0.3,0.3,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,300,7,20,10,0.3,0.3,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,300,7,20,3,0.3,0.3,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,300,7,200,3,0.3,0.2,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,300,7,200,5,0.3,1,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,200,9999,4,1,0,4,1,1)": 1, 
   "ConjectureSymbolWeight(ConstPrio,3,400,4,50,50,0.7,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,300,200,1,2,400,0.1,4,2.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,300,200,7,0,400,0.1,4,2.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,300,300,10,100,2,4,0.5,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,300,300,7,200,2,0.3,0.5,0.8)": 1, 
   "ConjectureSymbolWeight(ConstPrio,400,400,18,200,4,2,3,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,7,400,7,7,9999,9999.9,4,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,-2,10,-1,50,0.8,3,1)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,-2,10,-1,50,4,3,0.5)": 4, 
   "ConjectureSymbolWeight(ConstPrio,9999,0,-1,7,9999,3,0.7,5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,0,1,20,50,3,3,0.3)": 2, 
   "ConjectureSymbolWeight(ConstPrio,9999,0,10,400,300,2,3,0.2)": 2, 
   "ConjectureSymbolWeight(ConstPrio,9999,0,4,20,50,3,3,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,1,50,7,9999,9999.9,3,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,100,3,20,300,0.2,3,1.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,100,7,50,50,1.5,1.5,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,18,4,18,50,0.7,3,0.8)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,2,1,2,100,2.5,1,5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,2,200,10,9999,9999.9,3,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,20,10,50,50,4,2,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,200,10,400,100,2,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,200,4,50,0,4,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,200,7,50,50,4,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,3,0,100,100,2.5,1,3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,4,-1,7,20,4,2,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,400,1,-2,0,4,1,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,400,1,-2,2,4,0.7,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,400,10,-2,0,4,0.5,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,400,10,3,50,5,1.5,1)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,10,18,50,4,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,10,20,50,5,3,0.3)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,10,20,50,5,3,0.5)": 2, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,10,50,50,4,3,0.5)": 25, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,10,7,9999,0.8,3,0.5)": 2, 
   "ConjectureSymbolWeight(ConstPrio,9999,5,3,400,50,4,3,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,50,-1,18,50,4,3,1)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,50,-1,200,50,4,3,1)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,50,-1,7,50,0.8,3,0.7)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,7,10,3,9999,3,0.7,5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,7,18,50,50,0.7,1.5,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,7,4,20,9999,9999.9,3,0.3)": 2, 
   "ConjectureSymbolWeight(ConstPrio,9999,9999,-1,7,50,5,2,4)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,9999,-2,4,50,5,2,1.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,9999,1,0,18,2.5,2,0.5)": 1, 
   "ConjectureSymbolWeight(ConstPrio,9999,9999,18,400,200,1.5,3,0.3)": 1, 
   "ConjectureSymbolWeight(DeferSOS,400,20,4,4,3,4,1,0.8)": 1, 
   "ConjectureSymbolWeight(PreferGoals,18,300,-2,7,1,2,0.5,3)": 1, 
   "ConjectureSymbolWeight(PreferGoals,200,-1,50,200,-2,2,3,1)": 1, 
   "ConjectureSymbolWeight(PreferGoals,7,200,10,18,4,3,0.2,0.3)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,100,1,-1,5,3,0.8,5,0.2)": 2, 
   "ConjectureSymbolWeight(PreferGroundGoals,100,10,1,10,50,0.8,0.7,0.7)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,100,10,1,18,50,0.7,0.8,0.8)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,100,5,1,-2,50,3,3,0.5)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,100,5,5,-2,50,3,3,0.5)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,-1,4,4,1,9999.9,3,0.2)": 2, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,-1,5,50,-1,9999.9,3,0.2)": 2, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,-1,50,50,-1,9999.9,3,0.2)": 20, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,2,5,1,4,9999.9,0.7,0.2)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,200,0,20,-1,0.1,2.5,0.1)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,200,400,7,20,9999,0.3,1.5,2)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,300,200,3,1,400,0.1,4,2)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,9999,18,100,-1,-1,2,1.5,0.1)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,9999,3,-1,2,50,1,2,0.5)": 1, 
   "ConjectureSymbolWeight(PreferGroundGoals,9999,300,50,-2,4,2,0.1,4)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,200,-1,3,4,1,0.2,2,0.2)": 2, 
   "ConjectureSymbolWeight(PreferNonGoals,50,20,9999,50,400,1,9999.9,2)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,100,1,2,9999,3,5,0.5)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,200,10,-1,100,4,2,0.5)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,200,10,-1,9999,0.7,0.7,0.5)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,200,18,400,20,1.5,3,0.3)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,4,1,-1,100,4,4,0.5)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,9999,1,-2,50,2,4,0.2)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,9999,18,400,20,0.2,2.5,0.3)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,9999,18,400,20,1.5,3,0.3)": 1, 
   "ConjectureSymbolWeight(PreferNonGoals,9999,9999,18,50,20,1.5,3,0.3)": 1, 
   "ConjectureSymbolWeight(PreferProcessed,0,1,-1,0,3,2,0.5,1)": 1, 
   "ConjectureSymbolWeight(PreferProcessed,0,1,18,0,3,4,1,1)": 1, 
   "ConjectureSymbolWeight(PreferProcessed,20,10,3,7,5,2,0.1,1)": 2, 
   "ConjectureSymbolWeight(PreferProcessed,300,18,100,0,50,4,1,0.2)": 1, 
   "ConjectureSymbolWeight(PreferProcessed,400,10,100,50,50,4,2,0.1)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,10,3,100,400,10,0.2,0.3,2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,100,18,1,18,50,1,0.8,0.8)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,100,18,1,18,50,1.5,3,0.5)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,20,0,10,7,5,4,0.8,0.1)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,200,200,5,400,4,9999.9,0.7,0.2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,200,7,7,-2,300,0.2,1.5,0.5)": 2, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,300,9999,0,-2,18,4,2.5,2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,300,9999,0,-2,20,4,2.5,2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,300,9999,0,5,7,2.5,4,2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,400,300,-1,300,4,5,0.1,0.5)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,400,4,100,7,7,0.5,0.7,0.7)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,400,400,10,-1,400,0.1,4,2)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,50,-1,200,5,400,0.8,0.5,0.7)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,9999,3,-2,2,100,5,2,0.5)": 1, 
   "ConjectureSymbolWeight(PreferUnitGroundGoals,9999,400,10,400,10,2,1.5,0.5)": 1, 
   "ConjectureSymbolWeight(SimulateSOS,10,1,400,2,400,3,0.5,1)": 1, 
   "ConjectureSymbolWeight(SimulateSOS,18,20,-2,7,400,1.5,2.5,4)": 1, 
   "ConjectureSymbolWeight(SimulateSOS,9999,0,300,3,-2,9999.9,9999.9,0.3)": 1, 
   "ConjectureSymbolWeight(SimulateSOS,9999,300,10,400,3,9999.9,0.5,0.8)": 3, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,2,9999.9,0.1,0,3,0.5,9999.9)": 1, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,3,0,0.5,1,4,1,4)": 1, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,3,1,9999.9,0,9999.9,3,5)": 1, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,3,10,9999.9,0,0.1,1.5,3)": 1, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,3,10,9999.9,0,0.5,0.1,3)": 1, 
   "ConjectureTermPrefixWeight(ByCreationDate,1,3,9999.9,5,1,1,2,0.3)": 1, 
   "ConjectureTermPrefixWeight(ByNegLitDist,0,3,0.1,0.5,0,2,2.5,1.5)": 1, 
   "ConjectureTermPrefixWeight(ByNegLitDist,1,3,0,0.1,0,1.5,1,0.1)": 1, 
   "ConjectureTermPrefixWeight(ByNegLitDist,1,3,0.5,100,0,4,2.5,5)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,0,2,0.1,10,0,3,9999.9,9999.9)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,0,2,10,9999.9,1,1.5,2.5,1)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,0,2,9999.9,9999.9,0,4,0.3,2)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,0,0,0.5,2,2,5,2)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,0,0,10,0,0.8,1,0.7)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,1,0.5,100,0,0.8,3,5)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,2,10,0.5,1,2.5,0.5,4)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,3,0,10,0,0.5,1,0.1)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,3,0,10,0,9999.9,3,0.1)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,3,0.1,5,0,0.1,4,4)": 1, 
   "ConjectureTermPrefixWeight(ConstPrio,1,3,5,9999.9,2,5,5,5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,0,0,1,0.1,2,0.8,9999.9,2.5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,0,2,0,1,0,5,2.5,3)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,0,3,0,0.5,0,0.1,3,3)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,0,3,1,5,0,0.7,3,4)": 4, 
   "ConjectureTermPrefixWeight(DeferSOS,1,0,0,100,0,0.7,2,4)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,1,1,5,2,0.1,2,2)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,2,0.1,10,0,0.1,3,4)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,0.5,2,4,1,0.5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,10,0,0.1,1,5)": 2, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,10,0,0.1,4,4)": 40, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,10,0,0.2,2,0.7)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,10,0,1,3,0.3)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,100,0,0.1,1,5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.1,5,0,0.3,4,4)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.5,100,0,2.5,0.3,5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,0.5,9999.9,0,2,2.5,0.8)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,1,100,0,4,0.3,4)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,1,9999.9,0,5,4,0.5)": 1, 
   "ConjectureTermPrefixWeight(DeferSOS,1,3,5,100,0,2,0.3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferGoals,0,3,0.1,0.5,2,2.5,1,1.5)": 1, 
   "ConjectureTermPrefixWeight(PreferGoals,1,3,0,0.1,0,1,0.1,0.3)": 2, 
   "ConjectureTermPrefixWeight(PreferGoals,1,3,0,0.5,2,0.8,9999.9,4)": 1, 
   "ConjectureTermPrefixWeight(PreferGoals,1,3,10,9999.9,0,9999.9,0.3,2)": 1, 
   "ConjectureTermPrefixWeight(PreferGroundGoals,1,3,0.1,9999.9,0,0.7,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferGroundGoals,1,3,10,9999.9,0,0.7,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,0,2,5,5,0,0.7,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,0,3,100,100,0,0.2,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,1,0.1,0.1,2,0.8,2.5,3)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,1,1,5,2,0.1,2,2)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,2,10,9999.9,0,0.1,0.5,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0,10,0,3,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0,100,0,0.1,3,4)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0,100,1,4,3,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.1,9999.9,0,2,2.5,0.2)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.1,9999.9,0,3,3,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.1,9999.9,0,4,3,0.3)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.1,9999.9,0,9999.9,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.5,100,0,2,1.5,2)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.5,9999.9,0,4,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,0.5,9999.9,0,9999.9,3,0.7)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,1,9999.9,0,9999.9,3,4)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,10,9999.9,0,0.1,0.5,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,10,9999.9,0,9999.9,2,2)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,10,9999.9,0,9999.9,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,0.2,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,0.3,1,0.7)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,1,1,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,3,4,2.5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,4,0.7,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,0.7,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,3,5)": 61, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,4,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,100,9999.9,0,9999.9,5,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,100,0,0.2,5,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,0.3,3,1.5)": 3, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,1,0.8,5)": 2, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,1,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,3,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,9999.9,2,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,9999.9,2.5,5)": 1, 
   "ConjectureTermPrefixWeight(PreferNonGoals,1,3,5,9999.9,0,9999.9,3,5)": 50, 
   "ConjectureTermPrefixWeight(PreferProcessed,1,3,0.1,10,0,4,4,4)": 1, 
   "ConjectureTermPrefixWeight(PreferProcessed,1,3,100,9999.9,0,0.2,1,0.8)": 1, 
   "ConjectureTermPrefixWeight(PreferProcessed,1,3,100,9999.9,0,0.2,3,5)": 1, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,0,3,0,10,0,4,1,0.8)": 1, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,1,1,5,9999.9,0,9999.9,4,1.5)": 1, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,1,3,0,10,0,1.5,0.8,0.1)": 2, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,1,3,0.1,100,0,3,1,5)": 3, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,1,3,1,100,0,5,1,5)": 2, 
   "ConjectureTermPrefixWeight(PreferUnitGroundGoals,1,3,10,9999.9,0,1,0.8,5)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,0,3,0.1,9999.9,2,2,2.5,4)": 2, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,1,1,9999.9,1,9999.9,3,5)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,2,10,9999.9,0,9999.9,0.1,2.5)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,3,0.1,10,0,4,3,1)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,3,0.1,9999.9,0,4,9999.9,0.7)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,3,0.5,5,0,0.8,2,5)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,3,10,9999.9,0,0.7,4,1)": 1, 
   "ConjectureTermPrefixWeight(SimulateSOS,1,3,10,9999.9,0,9999.9,0.7,3)": 7, 
   "ConjectureTermTfIdfWeight(ByCreationDate,0,2,1,10,2,5,1,4)": 1, 
   "ConjectureTermTfIdfWeight(ByCreationDate,1,3,1,10,1,9999.9,1,0.8)": 1, 
   "ConjectureTermTfIdfWeight(ByCreationDate,1,3,1,9999.9,0,0.2,0.8,2)": 1, 
   "ConjectureTermTfIdfWeight(ByNegLitDist,0,2,1,10,0,1,0.1,2)": 1, 
   "ConjectureTermTfIdfWeight(ByNegLitDist,1,0,1,9999.9,1,1,2,9999.9)": 1, 
   "ConjectureTermTfIdfWeight(ByNegLitDist,1,3,0,1,1,3,2,2.5)": 2, 
   "ConjectureTermTfIdfWeight(ConstPrio,0,0,0,9999.9,1,3,3,4)": 1, 
   "ConjectureTermTfIdfWeight(ConstPrio,0,0,1,0,2,0.8,3,0.7)": 1, 
   "ConjectureTermTfIdfWeight(ConstPrio,1,0,0,9999.9,1,3,0.5,1)": 1, 
   "ConjectureTermTfIdfWeight(ConstPrio,1,3,0,9999.9,2,2,3,1)": 1, 
   "ConjectureTermTfIdfWeight(DeferSOS,1,1,0,10,1,0.2,1,0.8)": 1, 
   "ConjectureTermTfIdfWeight(DeferSOS,1,2,0,10,1,0.7,1.5,4)": 1, 
   "ConjectureTermTfIdfWeight(DeferSOS,1,3,0,9999.9,0,0.1,9999.9,9999.9)": 1, 
   "ConjectureTermTfIdfWeight(PreferGoals,0,0,1,1,1,0.7,2,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferGoals,0,3,1,0,0,4,2,1.5)": 1, 
   "ConjectureTermTfIdfWeight(PreferGoals,1,2,0,9999.9,2,0.2,1,0.3)": 1, 
   "ConjectureTermTfIdfWeight(PreferGroundGoals,0,2,1,10,2,0.3,3,5)": 1, 
   "ConjectureTermTfIdfWeight(PreferGroundGoals,0,2,1,9999.9,2,0.8,4,2.5)": 1, 
   "ConjectureTermTfIdfWeight(PreferGroundGoals,1,2,1,10,2,0.5,2.5,0.2)": 1, 
   "ConjectureTermTfIdfWeight(PreferNonGoals,0,0,0,9999.9,2,2,3,9999.9)": 1, 
   "ConjectureTermTfIdfWeight(PreferNonGoals,0,0,1,0,0,0.2,1,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferNonGoals,0,2,1,10,2,0.5,1,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferNonGoals,0,3,1,10,0,2,5,2)": 1, 
   "ConjectureTermTfIdfWeight(PreferProcessed,0,0,1,0,1,2,1,0.2)": 1, 
   "ConjectureTermTfIdfWeight(PreferProcessed,1,1,1,10,2,5,0.7,0.8)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,0,0,10,2,1,0.7,2)": 3, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,0,1,1,2,3,5,2)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,0,1,10,2,5,0.5,0.1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,0,1,9999.9,2,4,2,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,1,1,0,2,4,2,0.1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,1,1,10,0,3,4,0.8)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,1,1,10,2,1,0.2,0.1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,1,1,10,2,2,1,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,0,0,2,2,2,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,0,10,2,3,9999.9,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,0,9999.9,0,3,2,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,0.5,1,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,0.7,1.5,2)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,1,1.5,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,2,0.8,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,2,1,0.3)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,2,1,1)": 25, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,3,1,4)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,4,9999.9,2)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,9999.9,1,2)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,2,1,10,2,9999.9,4,1.5)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,0,3,1,10,2,9999.9,5,0.5)": 3, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,1,2,1,10,0,3,0.8,1)": 1, 
   "ConjectureTermTfIdfWeight(PreferUnitGroundGoals,1,3,0,10,0,2,3,0.5)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,0,0,0,9999.9,0,2.5,2,3)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,0,0,0,9999.9,1,0.8,2,4)": 11, 
   "ConjectureTermTfIdfWeight(SimulateSOS,0,0,0,9999.9,1,0.8,9999.9,0.1)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,0,0,0,9999.9,1,1.5,2,0.3)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,0,1,1,9999.9,1,2.5,2,1.5)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,1,0,0,0,1,0.7,0.7,9999.9)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,1,0,0,9999.9,1,0.5,0.7,5)": 1, 
   "ConjectureTermTfIdfWeight(SimulateSOS,1,0,0,9999.9,1,0.8,3,0.5)": 1, 
   "ConjectureTreeDistanceWeight(ByCreationDate,0,1,-1,300,2,1,2.5,2,3)": 1, 
   "ConjectureTreeDistanceWeight(ByCreationDate,0,1,-2,9999,2,1,1,0.7,4)": 7, 
   "ConjectureTreeDistanceWeight(PreferProcessed,0,1,0,18,0,1,0.8,0.8,1)": 1, 
   "ConjectureTreeDistanceWeight(PreferProcessed,0,1,5,400,-2,1,0.5,4,3)": 12, 
   "Defaultweight(ByCreationDate)": 7, 
   "Defaultweight(ByNegLitDist)": 24, 
   "Defaultweight(ConstPrio)": 19, 
   "Defaultweight(DeferSOS)": 52, 
   "Defaultweight(PreferGoals)": 12, 
   "Defaultweight(PreferGroundGoals)": 113, 
   "Defaultweight(PreferNonGoals)": 65, 
   "Defaultweight(PreferProcessed)": 12, 
   "Defaultweight(PreferUnitGroundGoals)": 22, 
   "Defaultweight(SimulateSOS)": 12, 
   "FIFOWeight(ByCreationDate)": 69, 
   "FIFOWeight(ByNegLitDist)": 53, 
   "FIFOWeight(ConstPrio)": 78, 
   "FIFOWeight(DeferSOS)": 223, 
   "FIFOWeight(PreferGoals)": 25, 
   "FIFOWeight(PreferGroundGoals)": 86, 
   "FIFOWeight(PreferNonGoals)": 243, 
   "FIFOWeight(PreferProcessed)": 417, 
   "FIFOWeight(PreferUnitGroundGoals)": 97, 
   "FIFOWeight(SimulateSOS)": 40, 
   "OrientLMaxWeight(ByNegLitDist,7,200,2,3,1.5)": 1, 
   "OrientLMaxWeight(ConstPrio,0,18,9999.9,0.8,0.7)": 1, 
   "OrientLMaxWeight(ConstPrio,2,1,0.7,5,2)": 24, 
   "OrientLMaxWeight(ConstPrio,2,1,2,3,2)": 2, 
   "OrientLMaxWeight(ConstPrio,2,4,0.5,3,3)": 1, 
   "OrientLMaxWeight(DeferSOS,20,5,4,4,0.5)": 1, 
   "OrientLMaxWeight(DeferSOS,3,7,0.7,5,2)": 1, 
   "OrientLMaxWeight(DeferSOS,5,50,0.1,9999.9,1.5)": 1, 
   "OrientLMaxWeight(PreferGoals,10,300,0.3,3,2.5)": 1, 
   "OrientLMaxWeight(PreferGroundGoals,10,0,3,0.3,2)": 1, 
   "OrientLMaxWeight(PreferNonGoals,2,1,0.3,5,1.5)": 2, 
   "OrientLMaxWeight(PreferNonGoals,4,-1,4,0.5,1.5)": 1, 
   "OrientLMaxWeight(PreferNonGoals,9999,0,5,0.8,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,-2,0,1,0.3,0.8)": 1, 
   "OrientLMaxWeight(PreferProcessed,0,0,2,0.1,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,1,0,2,2.5,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,1,0,3,0.3,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,1,1,3,0.5,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,1,18,0.8,0.5,2)": 3, 
   "OrientLMaxWeight(PreferProcessed,100,3,0.3,1.5,0.3)": 1, 
   "OrientLMaxWeight(PreferProcessed,18,0,3,1,2)": 1, 
   "OrientLMaxWeight(PreferProcessed,2,1,0.8,4,4)": 2, 
   "OrientLMaxWeight(PreferProcessed,2,7,5,1.5,4)": 1, 
   "OrientLMaxWeight(PreferProcessed,20,-2,4,1,5)": 2, 
   "OrientLMaxWeight(PreferProcessed,300,0,2,0.3,1.5)": 1, 
   "OrientLMaxWeight(PreferProcessed,4,0,3,0.3,2)": 11, 
   "OrientLMaxWeight(PreferProcessed,4,0,3,0.3,3)": 1, 
   "OrientLMaxWeight(PreferProcessed,9999,0,3,0.7,9999.9)": 1, 
   "OrientLMaxWeight(PreferProcessed,9999,0,9999.9,0.3,0.8)": 1, 
   "OrientLMaxWeight(PreferUnitGroundGoals,1,18,1,0.2,4)": 1, 
   "OrientLMaxWeight(PreferUnitGroundGoals,2,1,2,1,2)": 1, 
   "OrientLMaxWeight(PreferUnitGroundGoals,200,9999,1,0.8,2)": 1, 
   "OrientLMaxWeight(PreferUnitGroundGoals,4,-2,1,3,0.7)": 3, 
   "PNRefinedweight(ByNegLitDist,1,2,-1,10,0.2,0.5,0.3)": 1, 
   "PNRefinedweight(ByNegLitDist,7,9999,-2,7,3,1.5,0.1)": 1, 
   "PNRefinedweight(ByNegLitDist,9999,-1,7,4,0.7,4,2)": 1, 
   "PNRefinedweight(ByNegLitDist,9999,0,7,4,0.7,4,2)": 1, 
   "PNRefinedweight(ConstPrio,0,4,-2,200,1.5,4,2)": 1, 
   "PNRefinedweight(ConstPrio,200,400,10,0,4,0.3,0.2)": 1, 
   "PNRefinedweight(ConstPrio,400,5,-1,5,0.8,0.3,5)": 1, 
   "PNRefinedweight(ConstPrio,5,5,-1,5,2.5,3,5)": 1, 
   "PNRefinedweight(DeferSOS,100,7,-2,100,5,1,2)": 1, 
   "PNRefinedweight(DeferSOS,18,20,18,50,1,1,1)": 1, 
   "PNRefinedweight(DeferSOS,3,200,-2,18,5,1.5,2.5)": 1, 
   "PNRefinedweight(DeferSOS,5,3,18,4,0.8,9999.9,0.2)": 1, 
   "PNRefinedweight(PreferGoals,5,3,-1,5,1.5,3,5)": 1, 
   "PNRefinedweight(PreferGroundGoals,0,0,3,20,0.8,4,0.2)": 2, 
   "PNRefinedweight(PreferGroundGoals,0,4,-2,50,0.8,3,0.7)": 1, 
   "PNRefinedweight(PreferGroundGoals,1,5,300,300,3,0.5,0.2)": 1, 
   "PNRefinedweight(PreferGroundGoals,18,20,400,-1,9999.9,3,0.2)": 1, 
   "PNRefinedweight(PreferGroundGoals,20,3,-2,10,9999.9,3,0.1)": 1, 
   "PNRefinedweight(PreferGroundGoals,7,-1,5,0,9999.9,9999.9,2.5)": 1, 
   "PNRefinedweight(PreferNonGoals,-1,300,20,9999,1,3,0.8)": 2, 
   "PNRefinedweight(PreferNonGoals,20,50,50,10,0.8,0.5,4)": 1, 
   "PNRefinedweight(PreferNonGoals,300,18,4,20,0.8,0.3,0.2)": 21, 
   "PNRefinedweight(PreferNonGoals,300,3,4,20,4,0.2,0.2)": 1, 
   "PNRefinedweight(PreferNonGoals,400,10,4,20,0.5,0.3,0.1)": 1, 
   "PNRefinedweight(PreferProcessed,50,400,0,1,1,0.3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,0,1,-2,50,1,3,0.8)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,100,-2,18,2.5,3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,18,-2,18,4,4,0.5)": 2, 
   "PNRefinedweight(PreferUnitGroundGoals,18,2,5,18,0.7,2.5,0.2)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,20,-2,18,9999.9,3,0.5)": 22, 
   "PNRefinedweight(PreferUnitGroundGoals,18,20,-2,18,9999.9,4,0.5)": 2, 
   "PNRefinedweight(PreferUnitGroundGoals,18,20,-2,5,9999.9,5,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,300,0,18,5,3,0.5)": 2, 
   "PNRefinedweight(PreferUnitGroundGoals,18,300,0,18,9999.9,3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,4,200,18,2,4,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,50,4,18,9999.9,2,0.7)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,18,9999,-2,10,2,3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,200,50,-2,18,4,3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,300,3,200,18,0.3,5,0.2)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,5,-1,9999,3,2,3,0.5)": 1, 
   "PNRefinedweight(PreferUnitGroundGoals,5,20,2,18,9999.9,3,0.5)": 3, 
   "PNRefinedweight(SimulateSOS,0,7,-2,50,2.5,4,0.8)": 1, 
   "PNRefinedweight(SimulateSOS,4,-2,9999,20,0.7,0.2,4)": 1, 
   "Refinedweight(ByCreationDate,0,200,0.3,2,0.1)": 1, 
   "Refinedweight(ByCreationDate,1,10,9999.9,1.5,4)": 1, 
   "Refinedweight(ByCreationDate,1,18,9999.9,1.5,4)": 1, 
   "Refinedweight(ByCreationDate,1,300,9999.9,2,2)": 1, 
   "Refinedweight(ByCreationDate,10,10,4,1,5)": 1, 
   "Refinedweight(ByCreationDate,18,10,0.8,5,3)": 1, 
   "Refinedweight(ByCreationDate,18,10,1.5,1,5)": 1, 
   "Refinedweight(ByCreationDate,18,10,1.5,4,5)": 1, 
   "Refinedweight(ByCreationDate,2,200,0.3,4,0.8)": 1, 
   "Refinedweight(ByCreationDate,2,400,2,2,2)": 1, 
   "Refinedweight(ByCreationDate,2,9999,9999.9,3,1)": 1, 
   "Refinedweight(ByCreationDate,200,100,1.5,1,4)": 1, 
   "Refinedweight(ByCreationDate,3,100,2,5,0.3)": 1, 
   "Refinedweight(ByCreationDate,3,7,0.2,0.8,0.1)": 1, 
   "Refinedweight(ByCreationDate,50,2,2,0.3,0.2)": 1, 
   "Refinedweight(ByCreationDate,50,400,9999.9,0.5,1)": 1, 
   "Refinedweight(ByNegLitDist,1,7,3,3,0.2)": 1, 
   "Refinedweight(ByNegLitDist,18,20,0.7,5,2)": 1, 
   "Refinedweight(ByNegLitDist,2,200,0.2,3,0.1)": 1, 
   "Refinedweight(ByNegLitDist,3,2,0.8,4,4)": 1, 
   "Refinedweight(ConstPrio,100,100,0.5,1,9999.9)": 1, 
   "Refinedweight(DeferSOS,5,18,1,0.5,0.3)": 1, 
   "Refinedweight(DeferSOS,9999,0,2,2,3)": 1, 
   "Refinedweight(PreferGoals,1,2,5,3,0.7)": 1, 
   "Refinedweight(PreferGoals,18,50,9999.9,0.8,1.5)": 1, 
   "Refinedweight(PreferGoals,7,50,2,1,0.1)": 1, 
   "Refinedweight(PreferGoals,9999,9999,3,1.5,0.3)": 4, 
   "Refinedweight(PreferGroundGoals,-2,1,4,3,0.5)": 1, 
   "Refinedweight(PreferGroundGoals,10,100,3,0.1,3)": 1, 
   "Refinedweight(PreferGroundGoals,10,300,3,0.7,2)": 1, 
   "Refinedweight(PreferGroundGoals,100,100,2.5,2.5,0.8)": 9, 
   "Refinedweight(PreferGroundGoals,18,7,2.5,1.5,0.8)": 1, 
   "Refinedweight(PreferGroundGoals,20,100,0.7,1.5,0.5)": 4, 
   "Refinedweight(PreferGroundGoals,20,100,4,0.3,0.8)": 1, 
   "Refinedweight(PreferGroundGoals,20,100,5,4,0.8)": 38, 
   "Refinedweight(PreferGroundGoals,20,20,9999.9,3,0.8)": 1, 
   "Refinedweight(PreferGroundGoals,20,200,3,2.5,1.5)": 1, 
   "Refinedweight(PreferGroundGoals,7,100,9999.9,4,0.8)": 1, 
   "Refinedweight(PreferGroundGoals,7,18,1,0.1,0.5)": 1, 
   "Refinedweight(PreferNonGoals,-2,0,9999.9,3,3)": 1, 
   "Refinedweight(PreferNonGoals,20,100,0.2,0.2,0.7)": 1, 
   "Refinedweight(PreferProcessed,100,100,0.1,2.5,0.8)": 1, 
   "Refinedweight(PreferProcessed,3,200,2,1.5,2)": 1, 
   "Refinedweight(PreferProcessed,50,100,0.8,0.5,0.1)": 1, 
   "Refinedweight(PreferProcessed,50,100,4,3,1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,1,2,2,1.5,0.1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,20,100,0.3,0.2,0.2)": 1, 
   "Refinedweight(PreferUnitGroundGoals,20,100,1,0.2,0.1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,400,50,5,2,0.8)": 1, 
   "Refinedweight(PreferUnitGroundGoals,50,100,0.5,2,0.1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,50,100,0.8,1,0.1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,7,2,9999.9,0.3,0.1)": 1, 
   "Refinedweight(PreferUnitGroundGoals,7,300,2.5,2,0.7)": 4, 
   "Refinedweight(SimulateSOS,-2,9999,9999.9,1.5,0.1)": 1, 
   "Refinedweight(SimulateSOS,1,1,0.8,1.5,2)": 1, 
   "Refinedweight(SimulateSOS,1,1,2,1.5,2)": 20, 
   "Refinedweight(SimulateSOS,1,1,5,1.5,2)": 1, 
   "Refinedweight(SimulateSOS,1,20,1.5,1.5,2)": 1, 
   "Refinedweight(SimulateSOS,100,4,1,9999.9,2.5)": 2, 
   "Refinedweight(SimulateSOS,20,2,3,0.3,5)": 1, 
   "Refinedweight(SimulateSOS,3,2,1.5,3,2)": 1, 
   "Refinedweight(SimulateSOS,3,2,2,0.7,2)": 1, 
   "Refinedweight(SimulateSOS,3,2,2,1.5,2)": 2, 
   "Refinedweight(SimulateSOS,4,300,4,2,1.5)": 1, 
   "Refinedweight(SimulateSOS,400,0,0.2,0.8,1)": 4, 
   "RelevanceLevelWeight(ByCreationDate,1,0,2,1,4,18,1,20,1,0.7,1)": 1, 
   "RelevanceLevelWeight(ByCreationDate,1,2,2,2,-1,300,9999,50,1.5,3,0.7)": 1, 
   "RelevanceLevelWeight(ByCreationDate,1,2,2,2,4,400,100,-1,3,0.7,1)": 2, 
   "RelevanceLevelWeight(ByNegLitDist,0,2,0,1,3,-1,-1,1,5,2,0.5)": 1, 
   "RelevanceLevelWeight(ConstPrio,0,0,1,0,1,9999,18,10,3,0.8,1.5)": 1, 
   "RelevanceLevelWeight(ConstPrio,0,2,0,0,3,-1,-1,1,9999.9,1.5,0.5)": 1, 
   "RelevanceLevelWeight(ConstPrio,0,2,0,0,3,-1,-1,1,9999.9,2,0.5)": 18, 
   "RelevanceLevelWeight(ConstPrio,0,2,0,0,3,-1,-1,200,0.7,1.5,0.2)": 2, 
   "RelevanceLevelWeight(ConstPrio,0,2,0,0,3,-1,200,1,9999.9,2,0.5)": 2, 
   "RelevanceLevelWeight(ConstPrio,0,2,1,0,3,-1,200,-2,9999.9,2,0.5)": 1, 
   "RelevanceLevelWeight(ConstPrio,0,2,1,0,3,-1,200,1,9999.9,2,0.5)": 1, 
   "RelevanceLevelWeight(ConstPrio,1,2,2,2,-1,5,10,300,0.5,2,2)": 1, 
   "RelevanceLevelWeight(ConstPrio,1,2,2,2,2,7,50,18,3,0.7,1)": 1, 
   "RelevanceLevelWeight(ConstPrio,1,2,2,2,2,7,50,18,3,2,1)": 18, 
   "RelevanceLevelWeight(ConstPrio,1,2,2,2,50,10,9999,200,1,4,2)": 1, 
   "RelevanceLevelWeight(DeferSOS,1,1,0,0,3,5,9999,50,4,4,0.5)": 1, 
   "RelevanceLevelWeight(DeferSOS,1,1,0,0,3,7,9999,50,4,5,0.5)": 2, 
   "RelevanceLevelWeight(PreferGoals,2,1,0,2,5,-2,300,-1,3,0.2,4)": 1, 
   "RelevanceLevelWeight(PreferGroundGoals,0,0,1,0,5,0,50,4,9999.9,2,0.7)": 1, 
   "RelevanceLevelWeight(PreferGroundGoals,0,0,1,2,200,1,10,100,1.5,0.2,3)": 1, 
   "RelevanceLevelWeight(PreferGroundGoals,0,2,0,1,3,-1,0,3,9999.9,4,2)": 3, 
   "RelevanceLevelWeight(PreferGroundGoals,2,2,0,1,3,-1,0,3,9999.9,4,2)": 1, 
   "RelevanceLevelWeight(PreferProcessed,1,2,2,2,2,7,400,18,3,2,0.1)": 1, 
   "RelevanceLevelWeight(PreferUnitGroundGoals,0,0,1,0,18,50,18,9999,2,3,4)": 1, 
   "RelevanceLevelWeight(PreferUnitGroundGoals,0,0,1,0,5,1,10,100,5,2,0.1)": 2, 
   "RelevanceLevelWeight(PreferUnitGroundGoals,0,0,2,0,3,-2,2,2,5,9999.9,0.7)": 1, 
   "RelevanceLevelWeight(SimulateSOS,0,1,0,2,400,5,-1,10,1,5,2)": 1, 
   "RelevanceLevelWeight(SimulateSOS,0,2,2,0,5,20,9999,-1,0.1,4,1)": 1, 
   "RelevanceLevelWeight(SimulateSOS,1,1,1,2,300,9999,1,200,0.8,0.1,0.7)": 1, 
   "RelevanceLevelWeight(SimulateSOS,1,1,2,2,4,0,20,18,2.5,2.5,0.1)": 1, 
   "RelevanceLevelWeight2(ByCreationDate,2,0,1,0,400,300,0,400,2,3,2)": 1, 
   "RelevanceLevelWeight2(ByNegLitDist,1,2,2,1,4,-1,2,1,2,9999.9,9999.9)": 4, 
   "RelevanceLevelWeight2(ByNegLitDist,1,2,2,2,4,-1,2,1,1.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(ByNegLitDist,2,2,2,0,5,50,100,200,1.5,0.3,9999.9)": 1, 
   "RelevanceLevelWeight2(ByNegLitDist,2,2,2,2,5,-1,100,18,0.5,9999.9,9999.9)": 2, 
   "RelevanceLevelWeight2(ConstPrio,0,2,1,0,100,100,100,400,0.7,4,0.3)": 1, 
   "RelevanceLevelWeight2(ConstPrio,0,2,1,2,100,100,100,400,2,1.5,1)": 1, 
   "RelevanceLevelWeight2(ConstPrio,1,1,0,0,10,-2,1,7,1.5,4,4)": 1, 
   "RelevanceLevelWeight2(ConstPrio,1,1,0,1,10,-2,1,7,1.5,4,4)": 1, 
   "RelevanceLevelWeight2(ConstPrio,1,2,2,1,5,-1,-1,400,0.7,0.7,0.7)": 1, 
   "RelevanceLevelWeight2(DeferSOS,0,0,2,1,50,10,18,300,4,2,0.5)": 1, 
   "RelevanceLevelWeight2(DeferSOS,1,2,2,1,5,-1,300,50,0.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(DeferSOS,2,2,2,2,-1,-1,300,2,9999.9,0.8,2.5)": 1, 
   "RelevanceLevelWeight2(PreferGoals,0,2,1,0,7,10,10,100,5,2,5)": 1, 
   "RelevanceLevelWeight2(PreferGoals,0,2,2,1,3,0,7,300,4,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferGoals,1,2,2,0,-2,0,18,9999,0.7,5,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferGoals,2,2,2,1,-2,9999,200,400,4,0.3,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,1,0,1,1,4,7,400,50,0.8,0.3,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,1,1,2,1,50,-1,-2,1,1,1,3)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,1,2,2,1,2,-2,50,20,0.8,0.3,1)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,2,1,2,1,4,-1,-1,200,0.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,2,2,0,1,10,-2,4,1,2.5,5,3)": 1, 
   "RelevanceLevelWeight2(PreferGroundGoals,2,2,2,1,2,-2,50,50,0.7,0.3,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferNonGoals,0,1,1,1,10,20,100,400,0.8,1,0.7)": 1, 
   "RelevanceLevelWeight2(PreferNonGoals,1,1,0,1,20,-2,-2,1,0.5,4,2)": 1, 
   "RelevanceLevelWeight2(PreferNonGoals,2,0,1,2,9999,7,200,9999,9999.9,0.5,0.2)": 1, 
   "RelevanceLevelWeight2(PreferNonGoals,2,0,2,2,100,10,7,1,2,4,1)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,0,1,0,200,2,100,4,1,2,2.5)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,0,2,1,5,-1,2,5,3,4,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,1,1,0,50,50,0,400,0.1,5,2)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,1,1,2,5,20,100,5,0.3,9999.9,0.7)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,2,1,1,300,4,2,100,2.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,0,2,1,2,3,100,3,400,0.5,1.5,2.5)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,1,0,2,0,5,-1,4,3,4,3,2)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,1,2,0,1,100,-2,3,9999,4,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,1,2,2,0,3,-1,2,300,5,9999.9,9999.9)": 7, 
   "RelevanceLevelWeight2(PreferProcessed,1,2,2,0,4,-1,2,18,4,9999.9,9999.9)": 4, 
   "RelevanceLevelWeight2(PreferProcessed,1,2,2,1,4,-1,2,18,4,9999.9,9999.9)": 9, 
   "RelevanceLevelWeight2(PreferProcessed,1,2,2,1,4,1,2,18,4,9999.9,9999.9)": 3, 
   "RelevanceLevelWeight2(PreferProcessed,2,0,0,1,300,-2,9999,400,1,2,9999.9)": 1, 
   "RelevanceLevelWeight2(PreferProcessed,2,1,1,0,-1,-2,4,9999,0.1,0.1,3)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,0,2,0,1,10,0,-1,0,0.2,4,1.5)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,1,0,1,200,-1,4,7,4,4,1.5)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,1,0,1,300,-2,-2,1,1,4,3)": 22, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,1,0,1,300,-2,4,-1,0.3,4,0.1)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,2,0,0,50,20,3,2,9999.9,0.7,0.1)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,2,0,1,10,-2,3,1,1,4,3)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,2,0,2,5,-2,-2,0,1.5,4,2)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,1,2,2,1,20,18,400,400,4,1,0.7)": 1, 
   "RelevanceLevelWeight2(PreferUnitGroundGoals,2,1,0,0,18,18,0,0,0.5,3,5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,0,1,2,9999,100,100,400,4,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,0,300,400,7,9999,1,5,4)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,-2,200,400,1.5,5,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,20,3,4,1.5,3,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,200,18,50,1,5,4)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,0,400,200,7,10,1,5,4)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,1,50,10,100,400,5,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,1,50,50,100,3,2,0.3,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,2,0,100,0,400,5,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,2,0,100,1,400,4,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,2,100,-2,100,400,3,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,2,100,1,7,400,4,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,1,2,400,-1,200,400,3,5,2)": 2, 
   "RelevanceLevelWeight2(SimulateSOS,0,1,2,0,400,-1,200,18,2,2,0.2)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,0,100,4,9999,400,1,5,4)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,0,4,100,3,400,0.1,1.5,2.5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,0,400,-1,300,400,1.5,5,3)": 2, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,0,400,-2,200,400,1.5,5,3)": 33, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,0,50,4,9999,400,4,5,4)": 5, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,-2,100,400,0.7,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,100,100,400,1.5,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,5,200,400,1,0.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,1,2,18,100,100,400,0.5,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,0,2,2,1,3,-1,-1,50,3,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,0,0,1,10,400,4,1,9999.9,4,2)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,0,2,0,5,5,300,400,4,9999.9,5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,0,2,1,5,-1,0,50,0.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,0,2,1,7,2,9999,50,4,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,0,2,2,4,1,50,50,9999.9,0.3,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,0,1,7,-1,0,400,0.5,4,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,1,0,100,100,100,400,0.7,1.5,1)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,1,0,100,100,100,400,1.5,1.5,1)": 2, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,1,0,400,-2,200,300,3,4,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,1,0,9999,2,200,0,5,5,2)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,1,1,20,4,9999,20,4,5,4)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,10,0,300,100,0.7,0.1,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,200,-1,0,300,3,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,4,-1,400,50,4,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,-1,50,0.5,9999.9,9999.9)": 32, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,-1,50,1,9999.9,1.5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,3,50,0.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,300,18,2,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,400,50,4,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,1,2,2,1,5,-1,7,50,2,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,0,1,0,-1,1,4,200,0.1,0.1,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,0,1,0,50,4,20,200,0.1,0.1,2.5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,0,1,0,50,4,7,200,0.1,0.1,2.5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,0,1,1,2,-1,3,2,4,4,2.5)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,0,2,1,300,400,400,100,2,2.5,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,2,0,1,400,50,0,400,0.7,0.2,1.5)": 2, 
   "RelevanceLevelWeight2(SimulateSOS,2,2,1,0,100,2,200,200,3,5,3)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,2,2,1,5,-1,-1,50,2.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,2,2,1,5,-2,-1,50,0.5,9999.9,9999.9)": 1, 
   "RelevanceLevelWeight2(SimulateSOS,2,2,2,2,400,200,100,1,0.1,9999.9,1)": 1, 
   "StaggeredWeight(ByCreationDate,1)": 16, 
   "StaggeredWeight(ByCreationDate,1.5)": 15, 
   "StaggeredWeight(ByCreationDate,2)": 11, 
   "StaggeredWeight(ByNegLitDist,1)": 25, 
   "StaggeredWeight(ByNegLitDist,1.5)": 4, 
   "StaggeredWeight(ByNegLitDist,2)": 7, 
   "StaggeredWeight(ConstPrio,1)": 24, 
   "StaggeredWeight(ConstPrio,1.5)": 6, 
   "StaggeredWeight(ConstPrio,2)": 21, 
   "StaggeredWeight(DeferSOS,1)": 227, 
   "StaggeredWeight(DeferSOS,1.5)": 162, 
   "StaggeredWeight(DeferSOS,2)": 163, 
   "StaggeredWeight(PreferGoals,1)": 18, 
   "StaggeredWeight(PreferGoals,1.5)": 4, 
   "StaggeredWeight(PreferGoals,2)": 4, 
   "StaggeredWeight(PreferGroundGoals,1)": 44, 
   "StaggeredWeight(PreferGroundGoals,1.5)": 29, 
   "StaggeredWeight(PreferGroundGoals,2)": 16, 
   "StaggeredWeight(PreferNonGoals,1)": 35, 
   "StaggeredWeight(PreferNonGoals,1.5)": 18, 
   "StaggeredWeight(PreferNonGoals,2)": 30, 
   "StaggeredWeight(PreferProcessed,1)": 15, 
   "StaggeredWeight(PreferProcessed,1.5)": 13, 
   "StaggeredWeight(PreferProcessed,2)": 17, 
   "StaggeredWeight(PreferUnitGroundGoals,1)": 25, 
   "StaggeredWeight(PreferUnitGroundGoals,1.5)": 23, 
   "StaggeredWeight(PreferUnitGroundGoals,2)": 16, 
   "StaggeredWeight(SimulateSOS,1)": 18, 
   "StaggeredWeight(SimulateSOS,1.5)": 4, 
   "SymbolTypeweight(ByCreationDate,4,200,0,10,3,3,0.8)": 1, 
   "SymbolTypeweight(ByNegLitDist,-1,1,-1,0,0.5,2,1.5)": 1, 
   "SymbolTypeweight(ConstPrio,-2,2,-2,20,1.5,2,0.3)": 1, 
   "SymbolTypeweight(ConstPrio,-2,7,-1,5,9999.9,4,0.8)": 1, 
   "SymbolTypeweight(ConstPrio,50,100,4,100,0.2,1,3)": 1, 
   "SymbolTypeweight(DeferSOS,100,2,0,300,2.5,3,1)": 1, 
   "SymbolTypeweight(DeferSOS,20,7,-1,1,9999.9,1,1.5)": 2, 
   "SymbolTypeweight(DeferSOS,5,300,20,4,5,9999.9,5)": 1, 
   "SymbolTypeweight(PreferGoals,200,3,7,200,0.5,0.1,0.2)": 1, 
   "SymbolTypeweight(PreferGroundGoals,-2,0,-1,3,1.5,1.5,4)": 1, 
   "SymbolTypeweight(PreferGroundGoals,-2,300,100,-1,2,2,1)": 1, 
   "SymbolTypeweight(PreferGroundGoals,3,3,-2,1,2,2,9999.9)": 1, 
   "SymbolTypeweight(PreferGroundGoals,50,3,18,2,0.5,3,0.2)": 1, 
   "SymbolTypeweight(PreferNonGoals,200,100,100,18,0.8,2,3)": 1, 
   "SymbolTypeweight(PreferNonGoals,3,0,0,-2,0.1,3,2)": 1, 
   "SymbolTypeweight(PreferProcessed,10,0,-1,4,0.3,4,0.2)": 1, 
   "SymbolTypeweight(PreferProcessed,10,1,-1,4,0.5,2,1)": 2, 
   "SymbolTypeweight(PreferProcessed,100,20,-2,5,0.8,1.5,5)": 1, 
   "SymbolTypeweight(PreferProcessed,18,100,2,200,1.5,2,3)": 1, 
   "SymbolTypeweight(PreferProcessed,20,1,3,20,1,5,0.8)": 1, 
   "SymbolTypeweight(PreferUnitGroundGoals,400,7,3,100,3,1,2)": 1, 
   "SymbolTypeweight(SimulateSOS,-1,4,9999,-1,0.3,2,1)": 1, 
   "SymbolTypeweight(SimulateSOS,-2,1,0,-2,4,9999.9,0.8)": 1, 
   "SymbolTypeweight(SimulateSOS,-2,1,0,-2,4,9999.9,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,-2,1,0,-2,5,9999.9,1.5)": 2, 
   "SymbolTypeweight(SimulateSOS,-2,2,-2,20,1.5,1.5,0.2)": 1, 
   "SymbolTypeweight(SimulateSOS,1,1,-1,1,0.2,4,3)": 2, 
   "SymbolTypeweight(SimulateSOS,18,2,-1,7,5,2,1.5)": 3, 
   "SymbolTypeweight(SimulateSOS,20,-1,4,1,3,4,0.8)": 1, 
   "SymbolTypeweight(SimulateSOS,20,1,-1,3,9999.9,2,1.5)": 31, 
   "SymbolTypeweight(SimulateSOS,20,1,18,-2,9999.9,2,1.5)": 3, 
   "SymbolTypeweight(SimulateSOS,20,300,-1,1,9999.9,1,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,20,400,0,9999,0.3,1,5)": 1, 
   "SymbolTypeweight(SimulateSOS,20,50,9999,2,4,4,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,20,7,-1,1,9999.9,2,1.5)": 22, 
   "SymbolTypeweight(SimulateSOS,20,7,-1,50,5,2,1.5)": 4, 
   "SymbolTypeweight(SimulateSOS,20,9999,-1,1,9999.9,2,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,3,1,-1,1,0.8,2,9999.9)": 1, 
   "SymbolTypeweight(SimulateSOS,3,1,-1,1,0.8,2.5,9999.9)": 1, 
   "SymbolTypeweight(SimulateSOS,3,1,-1,1,2,2,9999.9)": 13, 
   "SymbolTypeweight(SimulateSOS,3,1,-1,1,3,1.5,9999.9)": 1, 
   "SymbolTypeweight(SimulateSOS,3,1,0,-2,1,1,4)": 1, 
   "SymbolTypeweight(SimulateSOS,3,2,-1,1,5,2.5,9999.9)": 3, 
   "SymbolTypeweight(SimulateSOS,300,300,1,50,3,2,5)": 1, 
   "SymbolTypeweight(SimulateSOS,5,4,-1,1,0.5,2,9999.9)": 1, 
   "SymbolTypeweight(SimulateSOS,5,7,0,4,0.5,0.2,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,50,1,2,300,0.8,2,2)": 1, 
   "SymbolTypeweight(SimulateSOS,7,100,2,-1,1.5,2,1.5)": 2, 
   "SymbolTypeweight(SimulateSOS,7,20,18,2,3,1,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,7,400,50,400,9999.9,1,1.5)": 1, 
   "SymbolTypeweight(SimulateSOS,9999,7,-1,3,3,2,4)": 2, 
   "SymbolTypeweight(SimulateSOS,9999,7,-1,3,4,2,4)": 1, 
   "Uniqweight(ByCreationDate)": 26, 
   "Uniqweight(ByNegLitDist)": 13, 
   "Uniqweight(ConstPrio)": 21, 
   "Uniqweight(DeferSOS)": 98, 
   "Uniqweight(PreferGoals)": 16, 
   "Uniqweight(PreferGroundGoals)": 10, 
   "Uniqweight(PreferNonGoals)": 17, 
   "Uniqweight(PreferProcessed)": 68, 
   "Uniqweight(PreferUnitGroundGoals)": 15, 
   "Uniqweight(SimulateSOS)": 122
}

def extend_cefs(cefs, params):
   "Extend cefs with CEFs from params."

   keys = [x for x in params if x.startswith("cef")]
   for key in keys:
      cef = params[key]
      if cef not in cefs:
         log("Extending CEFS with %s"%cef)
         cefs.append(cef)

def setup():
   "Read CEF collection, set up directories, and reset best found params."
  
   if not exists("empty.tst"):
      file("empty.tst","w").write("")
   
   cefs = epymils.cefs.bests(50, cefs=CEFS)
   params = epymils.params.make_params(file(sys.argv[1]).read().strip().split())
   extend_cefs(cefs, params)
      
   log("CEFS:", ["[%2d] %s"%(n,s) for (n,s) in enumerate(map(epymils.params.block2cef,cefs))])

   return (cefs, params, sys.argv[2])

def run():
   (cefs, params, f_problems) = setup()
   log_params(params, "PARAMILS INPUT:")
   (params, info) = paramils.run_globaltune(int(time.time()*1000), cefs, params, f_problems=f_problems, out=True)
   print eargs.e_proto(params)

if len(sys.argv) != 3:
   print "usage: %s strat probs" % sys.argv[0]
else:
   run()

